@@ -36,7 +36,7 @@ extern "C" {
         catch (z3_exception & ex) {
             // The error handler is only available for contexts
             // Just throw a warning.
-            warning_msg("%s", ex.msg());
+            warning_msg("%s", ex.what());
         }
     }
 
@@ -59,7 +59,7 @@ extern "C" {
         catch (z3_exception & ex) {
             // The error handler is only available for contexts
             // Just throw a warning.
-            warning_msg("%s", ex.msg());
+            warning_msg("%s", ex.what());
             return false;
         }
     }
@@ -69,7 +69,7 @@ extern "C" {
         LOG_Z3_get_global_param_descrs(c);
         Z3_param_descrs_ref * d = alloc(Z3_param_descrs_ref, *mk_c(c));
         mk_c(c)->save_object(d);
-        d->m_descrs = gparams::get_global_param_descrs();
+        d->m_descrs.copy(const_cast<param_descrs&>(gparams::get_global_param_descrs()));
         auto r = of_param_descrs(d);
         RETURN_Z3(r);
         Z3_CATCH_RETURN(nullptr);
@@ -84,7 +84,7 @@ extern "C" {
         } catch (z3_exception & ex) {
             // The error handler is only available for contexts
             // Just throw a warning.
-            warning_msg("%s", ex.msg());
+            warning_msg("%s", ex.what());
             return nullptr;
         }
     }
@@ -106,7 +106,7 @@ extern "C" {
         catch (z3_exception & ex) {
             // The error handler is only available for contexts
             // Just throw a warning.
-            warning_msg("%s", ex.msg());
+            warning_msg("%s", ex.what());
         }
     }
 
