@@ -119,13 +119,13 @@ public class Sort extends AST
         switch (sk)
         {
         case Z3_ARRAY_SORT:
-            return new ArraySort(ctx, obj);
+            return new ArraySort<>(ctx, obj);
         case Z3_BOOL_SORT:
             return new BoolSort(ctx, obj);
         case Z3_BV_SORT:
             return new BitVecSort(ctx, obj);
         case Z3_DATATYPE_SORT:
-            return new DatatypeSort(ctx, obj);
+            return new DatatypeSort<>(ctx, obj);
         case Z3_INT_SORT:
             return new IntSort(ctx, obj);
         case Z3_REAL_SORT:
@@ -141,9 +141,9 @@ public class Sort extends AST
         case Z3_ROUNDING_MODE_SORT:
             return new FPRMSort(ctx, obj);
         case Z3_SEQ_SORT:
-            return new SeqSort(ctx, obj);
+            return new SeqSort<>(ctx, obj);
         case Z3_RE_SORT:
-            return new ReSort(ctx, obj);
+            return new ReSort<>(ctx, obj);
         default:
             throw new Z3Exception("Unknown sort kind");
         }
