@@ -16,8 +16,7 @@ Author:
 Revision History:
 
 --*/
-#ifndef BIT2INT_H_
-#define BIT2INT_H_
+#pragma once
 
 #include "ast/bv_decl_plugin.h"
 #include "ast/arith_decl_plugin.h"
@@ -88,5 +87,4 @@ public:
     void operator()(expr * m, expr_ref & result, proof_ref& p);
 };
 
-#endif /* BIT2INT_H_ */
 
