@@ -106,7 +106,7 @@ protected:
     void end_scope();
     bool is_child_of_top_frame(expr * t) const;
     void set_new_child_flag(expr * old_t) {
-        CTRACE("rewriter_bug", !is_child_of_top_frame(old_t), display_stack(tout, 3););
+        CTRACE(rewriter_bug, !is_child_of_top_frame(old_t), display_stack(tout, 3););
         SASSERT(is_child_of_top_frame(old_t));
         if (!m_frame_stack.empty())
             m_frame_stack.back().m_new_child = true;
@@ -189,7 +189,7 @@ public:
 */
 class inv_var_shifter : public var_shifter_core {
 protected:
-    unsigned m_shift;
+    unsigned m_shift = 0;
     void process_var(var * v) override;
 public:
     inv_var_shifter(ast_manager & m):var_shifter_core(m) {}
