@@ -548,7 +548,7 @@ struct th_rewriter_cfg : public default_rewriter_cfg {
         func_decl * f_prime = nullptr;
         expr_ref new_t(m()), new_e(m()), common(m());
         bool first;
-        TRACE("push_ite", tout << "unifying:\n" << mk_ismt2_pp(t, m()) << "\n" << mk_ismt2_pp(e, m()) << "\n";);
+        TRACE(push_ite, tout << "unifying:\n" << mk_ismt2_pp(t, m()) << "\n" << mk_ismt2_pp(e, m()) << "\n";);
         if (unify(t, e, f_prime, new_t, new_e, common, first)) {
             if (first)
                 result = m().mk_app(f_prime, common, m().mk_ite(c, new_t, new_e));
@@ -556,7 +556,7 @@ struct th_rewriter_cfg : public default_rewriter_cfg {
                 result = m().mk_app(f_prime, m().mk_ite(c, new_t, new_e), common);
             return BR_DONE;
         }
-        TRACE("push_ite", tout << "failed\n";);
+        TRACE(push_ite, tout << "failed\n";);
         return BR_FAILED;
     }
 
@@ -632,7 +632,7 @@ struct th_rewriter_cfg : public default_rewriter_cfg {
         }
 
         if (st != BR_DONE && st != BR_FAILED) {
-            CTRACE("th_rewriter_step", st != BR_FAILED,
+            CTRACE(th_rewriter_step, st != BR_FAILED,
                    tout << f->get_name() << "\n";
                    for (unsigned i = 0; i < num; i++) tout << mk_ismt2_pp(args[i], m()) << "\n";
                    tout << "---------->\n" << mk_ismt2_pp(result, m()) << "\n";);
@@ -654,7 +654,7 @@ struct th_rewriter_cfg : public default_rewriter_cfg {
             st = m_ar_rw.mk_app_core(f,  num, args, result);
         }
 
-        CTRACE("th_rewriter_step", st != BR_FAILED,
+        CTRACE(th_rewriter_step, st != BR_FAILED,
                tout << f->get_name() << "\n";
                for (unsigned i = 0; i < num; i++) tout << mk_ismt2_pp(args[i], m()) << "\n";
                tout << "---------->\n" << mk_ismt2_pp(result, m()) << "\n";);
@@ -693,7 +693,7 @@ struct th_rewriter_cfg : public default_rewriter_cfg {
     }
 
     br_status extended_bv_eq(expr* a, expr* b, expr_ref& result) {
-        if (m_bv_util.is_bv2int(a) || m_bv_util.is_bv2int(b))
+        if (m_bv_util.is_ubv2int(a) || m_bv_util.is_ubv2int(b))
             return m_bv_rw.mk_eq_bv2int(a, b, result);
         return BR_FAILED;        
     }
@@ -823,7 +823,7 @@ struct th_rewriter_cfg : public default_rewriter_cfg {
                                        new_patterns_buf.size(), new_patterns_buf.data(), new_no_patterns_buf.size(), new_no_patterns_buf.data(),
                                        new_body);
             m_pinned.reset();
-            TRACE("reduce_quantifier", tout << mk_ismt2_pp(old_q, m()) << "\n----->\n" << mk_ismt2_pp(q1, m()) << "\n";);
+            TRACE(reduce_quantifier, tout << mk_ismt2_pp(old_q, m()) << "\n----->\n" << mk_ismt2_pp(q1, m()) << "\n";);
             SASSERT(is_well_sorted(m(), q1));
             if (m().proofs_enabled() && q1 != old_q) {
                 p1 = m().mk_rewrite(old_q, q1);
@@ -841,7 +841,7 @@ struct th_rewriter_cfg : public default_rewriter_cfg {
             result_pr = m().mk_transitivity(p1, p2);
         }
 
-        TRACE("reduce_quantifier", tout << "after elim_unused_vars:\n" << result << " " << result_pr << "\n" ;);
+        TRACE(reduce_quantifier, tout << "after elim_unused_vars:\n" << result << " " << result_pr << "\n" ;);
 
         proof_ref p2(m());
         expr_ref r(m());
@@ -933,9 +933,6 @@ struct th_rewriter::imp : public rewriter_tpl<th_rewriter_cfg> {
         return m_cfg.mk_eq(a, b);
     }
 
-    void set_solver(expr_solver* solver) {
-        m_cfg.m_seq_rw.set_solver(solver);
-    }
 };
 
 th_rewriter::th_rewriter(ast_manager & m, params_ref const & p):
@@ -1057,10 +1054,6 @@ expr_ref th_rewriter::mk_eq(expr* a, expr* b) {
     return m_imp->mk_eq(a, b);
 }
 
-void th_rewriter::set_solver(expr_solver* solver) {
-    m_imp->set_solver(solver);
-}
-
 
 bool th_rewriter::reduce_quantifier(quantifier * old_q, 
                                     expr * new_body, 
