@@ -46,3 +46,7 @@ public:
 
     bool supports_proofs() const override { return true; }
 };
+
+/*
+  ADD_SIMPLIFIER("pull-nested-quantifiers", "pull nested quantifiers to top-level.", "alloc(pull_nested_quantifiers_simplifier, m, p, s)")
+*/
