@@ -833,7 +833,7 @@ lbool hilbert_basis::saturate_orig(num_vector const& ineq, bool is_eq) {
     m_zero.reset();
     m_index->reset(m_current_ineq+1);
     int_table support;
-    TRACE("hilbert_basis", display_ineq(tout, ineq, is_eq););
+    TRACE(hilbert_basis, display_ineq(tout, ineq, is_eq););
     iterator it = begin();
     for (; it != end(); ++it) {
         offset_t idx = *it;
@@ -847,7 +847,7 @@ lbool hilbert_basis::saturate_orig(num_vector const& ineq, bool is_eq) {
             support.insert(idx.m_offset);
         }
     }
-    TRACE("hilbert_basis", display(tout););
+    TRACE(hilbert_basis, display(tout););
     // resolve passive into active
     offset_t j = alloc_vector();
     while (!m_passive->empty()) {
@@ -855,7 +855,7 @@ lbool hilbert_basis::saturate_orig(num_vector const& ineq, bool is_eq) {
             return l_undef;
         }
         offset_t idx = m_passive->pop();
-        TRACE("hilbert_basis", display(tout););
+        TRACE(hilbert_basis, display(tout););
         if (is_subsumed(idx)) {
             recycle(idx);
             continue;
@@ -886,7 +886,7 @@ lbool hilbert_basis::saturate_orig(num_vector const& ineq, bool is_eq) {
     m_active.reset();
     m_passive->reset();
     m_zero.reset();
-    TRACE("hilbert_basis", display(tout););
+    TRACE(hilbert_basis, display(tout););
     return m_basis.empty()?l_false:l_true;
 }
 
@@ -906,7 +906,7 @@ lbool hilbert_basis::saturate(num_vector const& ineq, bool is_eq) {
     m_index->reset(m_current_ineq+1);
     m_passive2->reset();
     m_sos.reset();
-    TRACE("hilbert_basis", display_ineq(tout, ineq, is_eq););
+    TRACE(hilbert_basis, display_ineq(tout, ineq, is_eq););
     unsigned init_basis_size = 0;
     for (unsigned i = 0; i < m_basis.size(); ++i) {
         offset_t idx = m_basis[i];
@@ -937,12 +937,12 @@ lbool hilbert_basis::saturate(num_vector const& ineq, bool is_eq) {
         }   
     }
 
-    TRACE("hilbert_basis", display(tout););
+    TRACE(hilbert_basis, display(tout););
     // resolve passive into active
     offset_t idx = alloc_vector();
     while (checkpoint() && !m_passive2->empty()) {
         offset_t sos, pas;
-        TRACE("hilbert_basis", display(tout); );
+        TRACE(hilbert_basis, display(tout); );
         unsigned offset = m_passive2->pop(sos, pas);
         SASSERT(can_resolve(sos, pas, true));
         resolve(sos, pas, idx);
@@ -978,7 +978,7 @@ lbool hilbert_basis::saturate(num_vector const& ineq, bool is_eq) {
     m_basis.append(m_zero);
     std::sort(m_basis.begin(), m_basis.end(), vector_lt_t(*this));
     m_zero.reset();
-    TRACE("hilbert_basis", display(tout););
+    TRACE(hilbert_basis, display(tout););
     return m_basis.empty()?l_false:l_true;
 }
 
@@ -1087,7 +1087,7 @@ void hilbert_basis::resolve(offset_t i, offset_t j, offset_t r) {
     for (unsigned k = 0; k < m_current_ineq; ++k) {
         u.weight(k) = v.weight(k) + w.weight(k);
     }
-    TRACE("hilbert_basis_verbose",
+    TRACE(hilbert_basis_verbose,
           display(tout, i); 
           display(tout, j); 
           display(tout, r); 
@@ -1115,7 +1115,7 @@ bool hilbert_basis::checkpoint() {
 }
 
 bool hilbert_basis::add_goal(offset_t idx) {
-    TRACE("hilbert_basis", display(tout, idx););
+    TRACE(hilbert_basis, display(tout, idx););
     values v = vec(idx);
     if (is_subsumed(idx)) {
         return false;
@@ -1308,7 +1308,7 @@ bool hilbert_basis::is_subsumed(offset_t i, offset_t j) const {
     for (unsigned k = 0; r && k < m_current_ineq; ++k) {
         r = v.weight(k) >= w.weight(k);
     }
-    CTRACE("hilbert_basis", r, 
+    CTRACE(hilbert_basis, r, 
            display(tout, i);
            tout << " <= \n";
            display(tout, j);
