@@ -30,7 +30,7 @@ namespace lp {
     };
     
     class int_solver::imp {
-        public:
+    public:
         int_solver&         lia;
         lar_solver&         lra;
         lar_core_solver&    lrac;
@@ -41,17 +41,17 @@ namespace lp {
         mpq                 m_k;               // the right side of the cut
         hnf_cutter          m_hnf_cutter;
         unsigned            m_hnf_cut_period;
-        unsigned            m_dioph_eq_period;
         dioph_eq            m_dio;  
         int_gcd_test        m_gcd;
-
+        unsigned            m_initial_dio_calls_period;
+        
         bool column_is_int_inf(unsigned j) const {
             return lra.column_is_int(j) && (!lia.value_is_int(j));
         }
 
         imp(int_solver& lia): lia(lia), lra(lia.lra), lrac(lia.lrac), m_hnf_cutter(lia), m_dio(lia), m_gcd(lia) {
             m_hnf_cut_period = settings().hnf_cut_period();
-            m_dioph_eq_period = settings().m_dioph_eq_period;
+            m_initial_dio_calls_period = settings().dio_calls_period();
         } 
 
         bool has_lower(unsigned j) const {
@@ -113,7 +113,7 @@ namespace lp {
                 }
                 // if bj == v, then, because we are patching the lra.get_value(v),
                 // we just need to assert that the lra.get_value(v) would be integral.
-                lp_assert(bj != v || lra.from_model_in_impq_to_mpq(new_val).is_int());
+                SASSERT(bj != v || lra.from_model_in_impq_to_mpq(new_val).is_int());
             }
         
             lra.set_value_for_nbasic_column(j, lia.get_value(j) + impq(delta));
@@ -126,6 +126,7 @@ namespace lp {
         }
 
         bool all_columns_are_integral() const {
+            return true; // otherwise it never returns true!
             for (lpvar j = 0; j < lra.number_of_vars(); j++)
                 if (!lra.column_is_int(j))
                     return false;
@@ -141,8 +142,8 @@ namespace lp {
                 return false;
             mpq a = fractional_part(c.coeff());
             mpq r = fractional_part(lra.get_value(v));
-            lp_assert(0 < r && r < 1);
-            lp_assert(0 < a && a < 1);
+            SASSERT(0 < r && r < 1);
+            SASSERT(0 < a && a < 1);
             mpq delta_plus, delta_minus;
             if (!get_patching_deltas(r, a, delta_plus, delta_minus))
                 return false;
@@ -158,7 +159,7 @@ namespace lp {
         lia_move patch_basic_columns() {
             lia.settings().stats().m_patches++;
             lra.remove_fixed_vars_from_base();
-            lp_assert(lia.is_feasible());
+            SASSERT(lia.is_feasible());
             for (unsigned j : lra.r_basis()) 
                 if (!lra.get_value(j).is_int() && lra.column_is_int(j) && !lia.is_fixed(j))
                     patch_basic_column(j);
@@ -174,12 +175,18 @@ namespace lp {
 
             if (r == lia_move::conflict) {
                 m_dio.explain(*this->m_ex);
-                m_dioph_eq_period = settings().m_dioph_eq_period;
+                lia.settings().dio_calls_period() = m_initial_dio_calls_period;
+                lia.settings().dio_enable_gomory_cuts() = false;
+                lia.settings().set_run_gcd_test(false);
                 return lia_move::conflict;
-            } else if (r == lia_move::branch)  {
-                m_dioph_eq_period = settings().m_dioph_eq_period;
-                return lia_move::branch;
-            } 
+            }
+            if (r == lia_move::undef) {
+                lia.settings().dio_calls_period() *= 2;
+                if (lra.settings().dio_calls_period() >= 16) {
+                    lia.settings().dio_enable_gomory_cuts() = true;
+                    lia.settings().set_run_gcd_test(true);
+                }
+            }
             return r;
         }
 
@@ -190,16 +197,19 @@ namespace lp {
         }
 
         bool should_gomory_cut() {
-            return (!settings().dio_eqs() || settings().dio_enable_gomory_cuts())
-                && m_number_of_calls % settings().m_int_gomory_cut_period == 0;
+            bool dio_allows_gomory = !settings().dio() || settings().dio_enable_gomory_cuts() ||
+                                      m_dio.some_terms_are_ignored();
+            return dio_allows_gomory && m_number_of_calls % settings().m_int_gomory_cut_period == 0;
         }
 
         bool should_solve_dioph_eq() {
-            return lia.settings().dio_eqs() && m_number_of_calls % m_dioph_eq_period == 0;
+            return lia.settings().dio() && (m_number_of_calls % settings().dio_calls_period() == 0);
         }
 
+        // HNF
+
         bool should_hnf_cut() {
-            return (!settings().dio_eqs() || settings().dio_enable_hnf_cuts())
+            return (!settings().dio() || settings().dio_enable_hnf_cuts())
                 && settings().enable_hnf() && m_number_of_calls % settings().hnf_cut_period() == 0;
         }
         
@@ -211,7 +221,6 @@ namespace lp {
                 m_hnf_cut_period = settings().hnf_cut_period();
             return r;
         }
-
         
         lia_move check(lp::explanation * e) {
             SASSERT(lra.ax_is_correct());
@@ -226,7 +235,7 @@ namespace lp {
         
             lia_move r = lia_move::undef;
 
-            if (m_gcd.should_apply())
+            if (m_gcd.should_apply() || (settings().dio() && m_dio.some_terms_are_ignored()))
                 r = m_gcd();
 
             check_return_helper pc(lra);
@@ -256,10 +265,10 @@ namespace lp {
 
         bool current_solution_is_inf_on_cut() const {
             SASSERT(cut_indices_are_columns());
-            const auto & x = lrac.m_r_x;
+            const auto & x = lrac.r_x();
             impq v = m_t.apply(x);
             mpq sign = m_upper ? one_of_type<mpq>()  : -one_of_type<mpq>();
-            CTRACE("current_solution_is_inf_on_cut", v * sign <= impq(m_k) * sign,
+            CTRACE(current_solution_is_inf_on_cut, v * sign <= impq(m_k) * sign,
                    tout << "m_upper = " << m_upper << std::endl;
                    tout << "v = " << v << ", k = " << m_k << std::endl;
                    tout << "term:";lra.print_term(m_t, tout) << "\n";
@@ -307,11 +316,11 @@ namespace lp {
                 if (abs(value.x) < small_value ||
                     (lra.column_has_upper_bound(j) && small_value > upper_bound(j).x - value.x) ||
                     (has_lower(j) && small_value > value.x - lower_bound(j).x)) {
-                    TRACE("int_solver", tout << "small j" << j << "\n");
+                    TRACE(int_solver, tout << "small j" << j << "\n");
                     add_column(true, r_small_value, n_small_value, j);
                     continue;
                 }
-                TRACE("int_solver", tout << "any j" << j << "\n");
+                TRACE(int_solver, tout << "any j" << j << "\n");
                 add_column(usage >= prev_usage, r_any_value, n_any_value, j);
                 if (usage > prev_usage) 
                     prev_usage = usage;
@@ -405,16 +414,16 @@ namespace lp {
         // coprime. We can find u and v such that u*a1 + v*x2 = 1.
         rational u, v;
         gcd(a1, x2, u, v);
-        lp_assert(gcd(a1, x2, u, v).is_one());
-        lp_assert((x + (a1 / a2) * (-u * t) * x1).is_int());
+        SASSERT(gcd(a1, x2, u, v).is_one());
+        SASSERT((x + (a1 / a2) * (-u * t) * x1).is_int());
         // 1 = (u- l*x2 ) * a1 + (v + l*a1)*x2, for every integer l.
         rational d = u * t * x1;
         // We can prove that x+alpha*d is integral,
         // and any other delta, satisfying x+alpha*delta, is equal to d modulo a2.
         delta_plus = mod(d, a2);
-        lp_assert(delta_plus > 0);
+        SASSERT(delta_plus > 0);
         delta_minus = delta_plus - a2;
-        lp_assert(delta_minus < 0);
+        SASSERT(delta_minus < 0);
 
         return true;
     }
@@ -423,7 +432,7 @@ namespace lp {
     
     int_solver::int_solver(lar_solver& lar_slv) :
         lra(lar_slv),
-        lrac(lra.m_mpq_lar_core_solver) {
+        lrac(lra.get_core_solver()) {
         m_imp = alloc(imp, *this);
         lra.set_int_solver(this);
     }
@@ -520,7 +529,7 @@ namespace lp {
         if (lrac.m_r_heading[j] >= 0 || is_fixed(j)) // basic or fixed var
             return false;
 
-        TRACE("random_update", display_column(tout, j) << ", is_int = " << column_is_int(j) << "\n";);
+        TRACE(random_update, display_column(tout, j) << ", is_int = " << column_is_int(j) << "\n";);
         impq const & xj = get_value(j);
 
         inf_l = true;
@@ -536,7 +545,7 @@ namespace lp {
     
 
         const auto & A = lra.A_r();
-        TRACE("random_update", tout <<  "m = " << m << "\n";);
+        TRACE(random_update, tout <<  "m = " << m << "\n";);
 
         auto delta = [](mpq const& x, impq const& y, impq const& z) {
             if (x.is_one())
@@ -551,7 +560,7 @@ namespace lp {
             const mpq & a = c.coeff();
             unsigned i = lrac.m_r_basis[row_index];
             impq const & xi = get_value(i);
-            lp_assert(lrac.m_r_solver.column_is_feasible(i));
+            SASSERT(lrac.m_r_solver.column_is_feasible(i));
             if (column_is_int(i) && !a.is_int() && xi.is_int()) 
                 m = lcm(m, denominator(a));
         
@@ -575,7 +584,7 @@ namespace lp {
         l += xj;
         u += xj;
 
-        TRACE("freedom_interval",
+        TRACE(freedom_interval,
               tout << "freedom variable for:\n";
               tout << lra.get_variable_name(j);
               tout << "[";
@@ -591,14 +600,14 @@ namespace lp {
 
 
     bool int_solver::is_feasible() const {
-        lp_assert(
+        SASSERT(
             lrac.m_r_solver.calc_current_x_is_feasible_include_non_basis() ==
             lrac.m_r_solver.current_x_is_feasible());
         return lrac.m_r_solver.current_x_is_feasible();
     }
 
     const impq & int_solver::get_value(unsigned j) const {
-        return lrac.m_r_x[j];
+        return lrac.r_x(j);
     }
 
     std::ostream& int_solver::display_column(std::ostream & out, unsigned j) const {
@@ -727,13 +736,13 @@ namespace lp {
         mpq r = a - b;
         if (!r.is_pos())
             return false;
-        TRACE("int_solver", tout << "a = " << a << ", b = " << b << ", r = " << r<< ", m = " << m << "\n";);
+        TRACE(int_solver, tout << "a = " << a << ", b = " << b << ", r = " << r<< ", m = " << m << "\n";);
         if (r < mpq(range))
             range = static_cast<unsigned>(r.get_uint64());
 
         mpq s = b + mpq(lra.settings().random_next() % (range + 1));
         impq new_val = x + m * impq(s);
-        TRACE("int_solver", tout << "new_val = " << new_val << "\n";);
+        TRACE(int_solver, tout << "new_val = " << new_val << "\n";);
         SASSERT(l <= new_val && new_val <= u);
         lra.set_value_for_nbasic_column(j, new_val);
         return true;
