@@ -27,8 +27,8 @@ lar_core_solver::lar_core_solver(
                m_r_heading,
                m_costs_dummy,
                m_column_types(),
-               m_r_lower_bounds(),
-               m_r_upper_bounds(),
+               m_r_lower_bounds,
+               m_r_upper_bounds,
                settings,
                column_names) {
 }    
@@ -76,31 +76,31 @@ void lar_core_solver::fill_not_improvable_zero_sum() {
 
 unsigned lar_core_solver::get_number_of_non_ints() const {
     unsigned n = 0;
-    for (auto & x : m_r_solver.m_x) 
+    for (auto & x : r_x()) 
         if (!x.is_int())
             n++;    
     return n;
 }
 
 void lar_core_solver::solve() {
-    TRACE("lar_solver", tout << m_r_solver.get_status() << "\n";);
-    lp_assert(m_r_solver.non_basic_columns_are_set_correctly());
-    lp_assert(m_r_solver.inf_heap_is_correct());
-	TRACE("find_feas_stats", tout << "infeasibles = " << m_r_solver.inf_heap_size() << ", int_infs = " << get_number_of_non_ints() << std::endl;);
+    TRACE(lar_solver, tout << m_r_solver.get_status() << "\n";);
+    SASSERT(m_r_solver.non_basic_columns_are_set_correctly());
+    SASSERT(m_r_solver.inf_heap_is_correct());
+	TRACE(find_feas_stats, tout << "infeasibles = " << m_r_solver.inf_heap_size() << ", int_infs = " << get_number_of_non_ints() << std::endl;);
 	if (m_r_solver.current_x_is_feasible() && m_r_solver.m_look_for_feasible_solution_only) {
         m_r_solver.set_status(lp_status::OPTIMAL);
-        TRACE("lar_solver", tout << m_r_solver.get_status() << "\n";);
+        TRACE(lar_solver, tout << m_r_solver.get_status() << "\n";);
         return;
 	}
     ++m_r_solver.m_settings.stats().m_need_to_solve_inf;
-    lp_assert( r_basis_is_OK());
+    SASSERT( r_basis_is_OK());
              
     if (m_r_solver.m_look_for_feasible_solution_only) //todo : should it be set?
          m_r_solver.find_feasible_solution();
     else 
         m_r_solver.solve();
     
-    lp_assert(r_basis_is_OK());
+    SASSERT(r_basis_is_OK());
     
     switch (m_r_solver.get_status())
     {
@@ -114,11 +114,11 @@ void lar_core_solver::solve() {
         m_r_solver.set_status(lp_status::OPTIMAL);
         break;
     }
-    lp_assert(r_basis_is_OK());
-    lp_assert(m_r_solver.non_basic_columns_are_set_correctly());
-    lp_assert(m_r_solver.inf_heap_is_correct());
+    SASSERT(r_basis_is_OK());
+    SASSERT(m_r_solver.non_basic_columns_are_set_correctly());
+    SASSERT(m_r_solver.inf_heap_is_correct());
 
-  TRACE("lar_solver", tout << m_r_solver.get_status() << "\n";);
+  TRACE(lar_solver, tout << m_r_solver.get_status() << "\n";);
 }
 
 } // namespace lp
