@@ -118,7 +118,7 @@ std::ostream& print_linear_combination_customized(const vector<std::pair<T, unsi
             }
         }
         if (val != 1) {
-            out << T_to_string(val);
+            out << T_to_string(val) << "*";
         }
         out << var_str(it.second);
     }
@@ -151,7 +151,6 @@ inline void throw_exception(std::string && str) {
 }
 typedef z3_exception exception;
 
-#define lp_assert(_x_) { SASSERT(_x_); }
 template <typename X> inline X zero_of_type() { return numeric_traits<X>::zero(); }
 template <typename X> inline X one_of_type() { return numeric_traits<X>::one(); }
 template <typename X> inline bool is_zero(const X & v) { return numeric_traits<X>::is_zero(v); }
