@@ -12,13 +12,13 @@
 
 namespace nla {
 class core;
-class new_lemma;
+class lemma_builder;
 class order: common {
 public:
     order(core *c) : common(c) {}
     void order_lemma();
     
-private:
+   private:
 
     bool order_lemma_on_ac_and_bc_and_factors(const monic& ac,
                                               const factor& a,
@@ -39,9 +39,9 @@ private:
     void order_lemma_on_factorization(const monic& rm, const factorization& ab);
     
 
-    void order_lemma_on_ab_gt(new_lemma& lemma, const monic& m, const rational& sign, lpvar a, lpvar b);
-    void order_lemma_on_ab_lt(new_lemma& lemma, const monic& m, const rational& sign, lpvar a, lpvar b);
-    void order_lemma_on_ab(new_lemma& lemma, const monic& m, const rational& sign, lpvar a, lpvar b, bool gt);
+    void order_lemma_on_ab_gt(lemma_builder& lemma, const monic& m, const rational& sign, lpvar a, lpvar b);
+    void order_lemma_on_ab_lt(lemma_builder& lemma, const monic& m, const rational& sign, lpvar a, lpvar b);
+    void order_lemma_on_ab(lemma_builder& lemma, const monic& m, const rational& sign, lpvar a, lpvar b, bool gt);
     void order_lemma_on_factor_binomial_explore(const monic& m, bool k);
     void order_lemma_on_factor_binomial_rm(const monic& ac, bool k, const monic& bd);
     void order_lemma_on_binomial_ac_bd(const monic& ac, bool k, const monic& bd, const factor& b, lpvar d);
