@@ -25,14 +25,14 @@ Revision History:
 #include <string>
 #include <algorithm>
 #include "math/lp/lp_settings.h"
-#include "math/lp/u_set.h"
+#include "util/uint_set.h"
 // see http://research.microsoft.com/projects/z3/smt07.pdf
 // The class searches for a feasible solution with as many different values of variables as it can find
 namespace lp {
 template <typename T> struct numeric_pair; // forward definition
 class lar_solver; // forward definition
 class random_updater {
-    u_set           m_var_set;
+    indexed_uint_set           m_var_set;
     lar_solver &    m_lar_solver;
     unsigned        m_range;
     bool shift_var(unsigned j);
