@@ -57,10 +57,6 @@ public:
     bool is_true(expr_ref_vector const& ts);
     bool are_equal(expr* s, expr* t);
 
-
-    void set_solver(expr_solver* solver);
-    bool has_solver();
-
     /**
      * best effort evaluator of extensional array equality.
      */
