@@ -16,8 +16,7 @@ Author:
 Revision History:
 
 --*/
-#ifndef DL_TABLE_RELATION_H_
-#define DL_TABLE_RELATION_H_
+#pragma once
 
 
 #include "muz/rel/dl_base.h"
@@ -129,5 +128,4 @@ namespace datalog {
 
 };
 
-#endif /* DL_TABLE_RELATION_H_ */
 
