@@ -16,8 +16,7 @@ Author:
 Revision History:
 
 --*/
-#ifndef KARR_RELATION_H_
-#define KARR_RELATION_H_
+#pragma once
 
 #include "muz/transforms/dl_mk_karr_invariants.h"
 #include "muz/rel/dl_relation_manager.h"
@@ -83,5 +82,4 @@ namespace datalog {
 
 };
 
-#endif /* DL_MK_KARR_INVARIANTS_H_ */
 
