@@ -16,8 +16,7 @@ Author:
 Revision History:
 
 --*/
-#ifndef SAT_ELIM_EQS_H_
-#define SAT_ELIM_EQS_H_
+#pragma once
 
 #include "sat/sat_types.h"
 #include "util/union_find.h"
@@ -50,4 +49,3 @@ namespace sat {
 
 };
 
-#endif
