@@ -35,7 +35,7 @@ namespace sat {
         m_mus.append(m_core);
         s.m_core.reset();
         s.m_core.append(m_mus);
-        TRACE("sat", tout << "new core: " << s.m_core << "\n";);
+        TRACE(sat, tout << "new core: " << s.m_core << "\n";);
     }
 
     void mus::update_model() {
@@ -56,7 +56,7 @@ namespace sat {
 
     lbool mus::mus1() {
         bool minimize_partial = s.m_config.m_core_minimize_partial;
-        TRACE("sat", tout << "old core: " << s.get_core() << "\n";);
+        TRACE(sat, tout << "old core: " << s.get_core() << "\n";);
         literal_vector& core = get_core();
         literal_vector& mus = m_mus;
         if (!minimize_partial && core.size() > 64) {
@@ -66,7 +66,7 @@ namespace sat {
             IF_VERBOSE(1, verbose_stream() << "(sat.mus num-to-process: " << core.size() << " mus: " << mus.size();
                        if (minimize_partial) verbose_stream() << " max-restarts: " << m_max_num_restarts;
                        verbose_stream() << ")\n";);
-            TRACE("sat", 
+            TRACE(sat, 
                   tout << "core: " << core << "\n";
                   tout << "mus:  " << mus  << "\n";);
 
@@ -88,7 +88,7 @@ namespace sat {
                 scoped_append _sa(mus, core);
                 mus.push_back(~lit); 
                 is_sat = s.check(mus.size(), mus.data());
-                TRACE("sat", tout << "mus: " << mus << "\n";);
+                TRACE(sat, tout << "mus: " << mus << "\n";);
             }
             IF_VERBOSE(1, verbose_stream() << "(sat.mus " << is_sat << ")\n";);
             switch (is_sat) {
@@ -115,7 +115,7 @@ namespace sat {
                     IF_VERBOSE(3, verbose_stream() << "(sat.mus unit reduction, literal is in both cores " << lit << ")\n";);
                 }
                 else {
-                    TRACE("sat", tout << "core: " << new_core << " mus: " << mus << "\n";);
+                    TRACE(sat, tout << "core: " << new_core << " mus: " << mus << "\n";);
                     core.reset();
                     for (unsigned i = 0; i < new_core.size(); ++i) {
                         literal lit = new_core[i];
