@@ -67,15 +67,8 @@ namespace sat {
         }
     };
 
-    unsigned scc::operator()() {
-        if (m_solver.m_inconsistent)
-            return 0;
-        if (!m_scc)
-            return 0;
-        CASSERT("scc_bug", m_solver.check_invariant());
-        report rpt(*this);
-        TRACE("scc", m_solver.display(tout););
-        TRACE("scc_details", m_solver.display_watches(tout););
+    bool scc::extract_roots(literal_vector& roots, bool_var_vector& to_elim) {
+        literal_vector lits;
         unsigned_vector index;
         unsigned_vector lowlink;
         unsigned_vector s;
@@ -84,11 +77,9 @@ namespace sat {
         index.resize(num_lits, UINT_MAX);
         lowlink.resize(num_lits, UINT_MAX);
         in_s.resize(num_lits, false);
-        literal_vector roots, lits;
         roots.resize(m_solver.num_vars(), null_literal);
         unsigned next_index = 0;
         svector<frame>   frames;
-        bool_var_vector  to_elim;
         
         for (unsigned l_idx = 0; l_idx < num_lits; l_idx++) {
             if (index[l_idx] != UINT_MAX)
@@ -145,7 +136,7 @@ namespace sat {
                 // visited all successors
                 if (lowlink[l_idx] == index[l_idx]) {
                     // found new SCC
-                    CTRACE("scc_cycle", s.back() != l_idx, {
+                    CTRACE(scc_cycle, s.back() != l_idx, {
                             tout << "cycle: ";
                             unsigned j = s.size() - 1;
                             unsigned l2_idx;
@@ -162,7 +153,7 @@ namespace sat {
                     bool_var v = l.var();
                     if (roots[v] != null_literal) {
                         // variable was already assigned... just consume stack
-                        TRACE("scc_detail", tout << "consuming stack...\n";);
+                        TRACE(scc_detail, tout << "consuming stack...\n";);
                         unsigned l2_idx;
                         do {
                             l2_idx = s.back();
@@ -173,7 +164,7 @@ namespace sat {
                     }
                     else {
                         // check if the SCC has an external variable, and check for conflicts
-                        TRACE("scc_detail", tout << "assigning roots...\n";);
+                        TRACE(scc_detail, tout << "assigning roots...\n";);
                         literal  r = null_literal;
                         unsigned j = s.size() - 1;
                         unsigned l2_idx;
@@ -182,7 +173,7 @@ namespace sat {
                             j--;
                             if (to_literal(l2_idx) == ~l) {
                                 m_solver.set_conflict();
-                                return 0;
+                                return false;
                             }
                             if (m_solver.is_external(to_literal(l2_idx).var())) {
                                 r = to_literal(l2_idx);
@@ -195,7 +186,7 @@ namespace sat {
                             r = to_literal(l_idx);
                         }
 
-                        TRACE("scc_detail", tout << "r: " << r << "\n";);
+                        TRACE(scc_detail, tout << "r: " << r << "\n";);
 
                         do {
                             l2_idx = s.back();
@@ -226,18 +217,34 @@ namespace sat {
                 roots[i] = literal(i, false);
             }
         }
-        TRACE("scc", for (unsigned i = 0; i < roots.size(); i++) { tout << i << " -> " << roots[i] << "\n"; }
+        return true;
+    }
+
+
+    unsigned scc::operator()() {
+        if (m_solver.m_inconsistent)
+            return 0;
+        if (!m_scc)
+            return 0;
+        CASSERT("scc_bug", m_solver.check_invariant());
+        report rpt(*this);
+        TRACE(scc, m_solver.display(tout););
+        TRACE(scc_details, m_solver.display_watches(tout););
+        literal_vector roots;
+        bool_var_vector to_elim;
+        if (!extract_roots(roots, to_elim))
+            return 0;
+        TRACE(scc, for (unsigned i = 0; i < roots.size(); i++) { tout << i << " -> " << roots[i] << "\n"; }
               tout << "to_elim: "; for (unsigned v : to_elim) tout << v << " "; tout << "\n";);
         m_num_elim += to_elim.size();
         elim_eqs eliminator(m_solver);
         eliminator(roots, to_elim);
-        TRACE("scc_detail", m_solver.display(tout););
+        TRACE(scc_detail, m_solver.display(tout););
         CASSERT("scc_bug", m_solver.check_invariant());
 
-        if (m_scc_tr) {
+        if (m_scc_tr) 
             reduce_tr();
-        }
-        TRACE("scc_detail", m_solver.display(tout););
+        TRACE(scc_detail, m_solver.display(tout););
         return to_elim.size();
     }
 
