@@ -33,7 +33,7 @@ Notes:
 #include "model/model_evaluator.h"
 #include "sat/sat_solver.h"
 #include "solver/simplifier_solver.h"
-#include "sat/sat_params.hpp"
+#include "params/sat_params.hpp"
 #include "sat/smt/euf_solver.h"
 #include "sat/tactic/goal2sat.h"
 #include "sat/tactic/sat2goal.h"
@@ -172,7 +172,7 @@ public:
         expr_ref_vector assumptions(m);
         for (unsigned i = 0; i < sz; ++i)
             assumptions.push_back(ensure_literal(_assumptions[i]));
-        TRACE("sat", tout << assumptions << "\n";);
+        TRACE(sat, tout << assumptions << "\n";);
         lbool r = internalize_formulas(assumptions);
         if (r != l_true)
             return r;
@@ -183,9 +183,9 @@ public:
             r = m_solver.check(m_dep.m_literals);
         }
         catch (z3_exception& ex) {
-            IF_VERBOSE(1, verbose_stream() << "exception: " << ex.msg() << "\n";);
+            IF_VERBOSE(1, verbose_stream() << "exception: " << ex.what() << "\n";);
             if (m.inc()) {
-                set_reason_unknown(std::string("(sat.giveup ") + ex.msg() + ')');
+                set_reason_unknown(std::string("(sat.giveup ") + ex.what() + ')');
                 return l_undef;
             }
             r = l_undef;            
@@ -426,6 +426,7 @@ public:
 
     expr* congruence_next(expr* e) override { return e; }
     expr* congruence_root(expr* e) override { return e; }
+    expr_ref congruence_explain(expr* a, expr* b) override { return expr_ref(m.mk_eq(a, b), m); }
     
 
     lbool find_mutexes(expr_ref_vector const& vars, vector<expr_ref_vector>& mutexes) override {
@@ -500,7 +501,7 @@ public:
         if (is_internalized() && m_internalized_converted) {            
             if (m_sat_mc) m_sat_mc->flush_smc(m_solver, m_map);
             m_cached_mc = concat(solver::get_model_converter().get(), m_sat_mc.get());
-            TRACE("sat", m_cached_mc->display(tout););
+            TRACE(sat, m_cached_mc->display(tout););
             return m_cached_mc;
         }
         else {
@@ -520,7 +521,7 @@ public:
         s2g(m_solver, m_map, m_params, g, m_sat_mc);
         m_internalized_fmls.reset();
         g.get_formulas(m_internalized_fmls);
-        TRACE("sat", m_solver.display(tout); tout << m_internalized_fmls << "\n";);
+        TRACE(sat, m_solver.display(tout); tout << m_internalized_fmls << "\n";);
         m_internalized_converted = true;
     }
 
@@ -564,6 +565,10 @@ public:
     void user_propagate_register_diseq(user_propagator::eq_eh_t& diseq_eh) override {
         ensure_euf()->user_propagate_register_diseq(diseq_eh);
     }
+
+    void user_propagate_register_on_binding(user_propagator::binding_eh_t& binding_eh) override {
+        ensure_euf()->user_propagate_register_on_binding(binding_eh);
+    }
     
     void user_propagate_register_expr(expr* e) override { 
         ensure_euf()->user_propagate_register_expr(e);
@@ -586,8 +591,9 @@ private:
 
     void add_assumption(expr* a) {
         init_goal2sat();
-        m_dep.insert(a, m_goal2sat.internalize(a));
-        get_euf()->add_assertion(a);
+        auto lit = m_goal2sat.internalize(a);
+        m_dep.insert(a, lit);
+        get_euf()->add_clause(1, &lit);
     }
 
     void internalize_assumptions(expr_ref_vector const& asms) {     
@@ -602,7 +608,7 @@ private:
         if (is_internalized() && assumptions.empty())
             return l_true;
 
-        TRACE("sat", tout << "qhead " << m_qhead << "\n");
+        TRACE(sat, tout << "qhead " << m_qhead << "\n");
 
         m_internalized_converted = false;
 
@@ -622,7 +628,7 @@ private:
             return;
         for (sat::literal c : m_solver.get_core()) 
             m_core.push_back(m_dep.lit2orig(c));
-        TRACE("sat",
+        TRACE(sat,
               tout << "core: " << m_solver.get_core() << "\n";
               tout << "core: " << m_core << "\n";
               m_solver.display(tout));
@@ -642,7 +648,7 @@ private:
     }
 
     void get_model_core(model_ref & mdl) override {
-        TRACE("sat", tout << "retrieve model " << (m_solver.model_is_current()?"present":"absent") << "\n";);
+        TRACE(sat, tout << "retrieve model " << (m_solver.model_is_current()?"present":"absent") << "\n";);
         mdl = nullptr;
         auto ext = get_euf();
         if (ext)
@@ -653,8 +659,8 @@ private:
             return;
         if (m_fmls.size() > m_qhead)
             return;
-        TRACE("sat", m_solver.display_model(tout););
-        CTRACE("sat", m_sat_mc, m_sat_mc->display(tout););
+        TRACE(sat, m_solver.display_model(tout););
+        CTRACE(sat, m_sat_mc, m_sat_mc->display(tout););
         sat::model ll_m = m_solver.get_model();
         mdl = alloc(model, m);
         if (m_sat_mc) 
@@ -678,12 +684,12 @@ private:
             }
         }
 
-        TRACE("sat", m_solver.display(tout););
+        TRACE(sat, m_solver.display(tout););
         if (m_sat_mc) 
             (*m_sat_mc)(mdl);
         m_goal2sat.update_model(mdl);
     
-        TRACE("sat", model_smt2_pp(tout, m, *mdl, 0););        
+        TRACE(sat, model_smt2_pp(tout, m, *mdl, 0););        
 
         if (gparams::get_ref().get_bool("model_validate", false)) {
             IF_VERBOSE(1, verbose_stream() << "Verifying solution\n";);
@@ -697,7 +703,7 @@ private:
                 eval(f, tmp);
                 if (m.limit().is_canceled())
                     return;
-                CTRACE("sat", !m.is_true(tmp),
+                CTRACE(sat, !m.is_true(tmp),
                        tout << "Evaluation failed: " << mk_pp(f, m) << " to " << tmp << "\n";
                        model_smt2_pp(tout, m, *(mdl.get()), 0););
                 if (m.is_false(tmp)) {
