@@ -21,6 +21,7 @@ Author:
 #include "ast/ast_translation.h"
 #include "ast/ast_util.h"
 #include "ast/euf/euf_egraph.h"
+#include "ast/euf/euf_mam.h"
 #include "ast/rewriter/th_rewriter.h"
 #include "ast/converters/model_converter.h"
 #include "sat/sat_extension.h"
@@ -30,7 +31,7 @@ Author:
 #include "sat/smt/user_solver.h"
 #include "sat/smt/euf_relevancy.h"
 #include "sat/smt/euf_proof_checker.h"
-#include "smt/params/smt_params.h"
+#include "params/smt_params.h"
 
 
 namespace euf {
@@ -83,7 +84,7 @@ namespace euf {
         expr* get_hint(euf::solver& s) const override;
     };
 
-    class solver : public sat::extension, public th_internalizer, public th_decompile, public sat::clause_eh {
+    class solver : public sat::extension, public th_internalizer, public th_decompile, public sat::clause_eh, public mam_solver {
         typedef top_sort<euf::enode> deps_t;
         friend class ackerman;
         friend class eq_proof_hint;
@@ -100,15 +101,6 @@ namespace euf {
             scope(unsigned l) : m_var_lim(l) {}
         };
 
-        struct local_search_config {
-            double cb = 0.0;
-            unsigned L = 20;
-            unsigned t = 45;
-            unsigned max_no_improve = 500000;
-            double sp = 0.0003;
-        };
-
-
         size_t* to_ptr(sat::literal l) { return TAG(size_t*, reinterpret_cast<size_t*>((size_t)(l.index() << 4)), 1); }
         size_t* to_ptr(size_t jst) { return TAG(size_t*, reinterpret_cast<size_t*>(jst), 2); }
         bool is_literal(size_t* p) const { return GET_TAG(p) == 1; }
@@ -127,7 +119,6 @@ namespace euf {
         sat::sat_internalizer&           si;
         relevancy                        m_relevancy;
         smt_params                       m_config;
-        local_search_config              m_ls_config;
         euf::egraph                      m_egraph;
         trail_stack                      m_trail;
         stats                            m_stats;
@@ -174,7 +165,7 @@ namespace euf {
         symbol                           m_smt = symbol("smt");            
         expr_ref_vector                  m_clause;
         expr_ref_vector                  m_expr_args;
-        expr_ref_vector                  m_assertions;
+        vector<sat::literal_vector>      m_top_level_clauses;
 
 
         // internalization
@@ -314,7 +305,7 @@ namespace euf {
         // accessors
         
         sat::sat_internalizer& get_si() { return si; }
-        ast_manager& get_manager() { return m; }
+        ast_manager& get_manager() override { return m; }
         enode* get_enode(expr* e) const { return m_egraph.find(e); }
         enode* bool_var2enode(sat::bool_var b) const {
             expr* e = m_bool_var2expr.get(b, nullptr);
@@ -324,8 +315,8 @@ namespace euf {
         sat::literal enode2literal(enode* n) const { return sat::literal(n->bool_var(), false); }
         lbool value(enode* n) const { return s().value(enode2literal(n)); }
         smt_params const& get_config() const { return m_config; }
-        region& get_region() { return m_trail.get_region(); }
-        egraph& get_egraph() { return m_egraph; }
+        region& get_region() override { return m_trail.get_region(); }
+        egraph& get_egraph() override { return m_egraph; }
         th_solver* fid2solver(family_id fid) const { return m_id2solver.get(fid, nullptr); }
 
         template <typename C>
@@ -341,6 +332,7 @@ namespace euf {
             push(push_back_trail< V, false>(vec));
         }
         trail_stack& get_trail_stack() { return m_trail; }
+        trail_stack& get_trail() override { return m_trail; }
 
         void updt_params(params_ref const& p);
         void set_solver(sat::solver* s) override { m_solver = s; use_drat(); }
@@ -356,7 +348,6 @@ namespace euf {
         void add_assumptions(sat::literal_set& assumptions) override;
         bool tracking_assumptions() override;
         std::string reason_unknown() override { return m_reason_unknown; }
-        lbool local_search(bool_vector& phase) override;
 
         void propagate(literal lit, ext_justification_idx idx);
         bool propagate(enode* a, enode* b, ext_justification_idx idx);
@@ -409,7 +400,7 @@ namespace euf {
         bool is_blocked(literal l, ext_constraint_idx) override;
         bool check_model(sat::model const& m) const override;
         void gc_vars(unsigned num_vars) override;
-        bool resource_limits_exceeded() const { return false; } // TODO
+        bool resource_limits_exceeded() const override { return false; } // TODO
 
 
         // proof
@@ -485,8 +476,10 @@ namespace euf {
         bool enable_ackerman_axioms(expr* n) const;
         bool is_fixed(euf::enode* n, expr_ref& val, sat::literal_vector& explain);
 
-        void add_assertion(expr* f);
-        expr_ref_vector const& get_assertions() { return m_assertions; }
+        // void add_assertion(expr* f);
+        // expr_ref_vector const& get_assertions() { return m_assertions; }
+        void add_clause(unsigned n, sat::literal const* lits);
+        vector <sat::literal_vector> const& top_level_clauses() const { return m_top_level_clauses; }
         model_ref get_sls_model();
 
         // relevancy
@@ -503,7 +496,7 @@ namespace euf {
         void add_aux(sat::literal a, sat::literal b) { sat::literal lits[2] = {a, b}; add_aux(2, lits); } 
         void add_aux(sat::literal a, sat::literal b, sat::literal c) { sat::literal lits[3] = { a, b, c }; add_aux(3, lits); }
         void mark_relevant(sat::literal lit) { m_relevancy.mark_relevant(lit); }
-        bool is_relevant(enode* n) const { return m_relevancy.is_relevant(n); }
+        bool is_relevant(enode* n) const override { return m_relevancy.is_relevant(n); }
         bool is_relevant(bool_var v) const;
         bool is_relevant(sat::literal lit) const { return is_relevant(lit.var()); }
         void relevant_eh(euf::enode* n);
@@ -561,6 +554,10 @@ namespace euf {
             check_for_user_propagator();
             m_user_propagator->register_decide(ceh);
         }
+        void user_propagate_register_on_binding(user_propagator::binding_eh_t& on_binding_eh) {
+            check_for_user_propagator();
+            NOT_IMPLEMENTED_YET();
+        }
         void user_propagate_register_expr(expr* e) {
             check_for_user_propagator();
             m_user_propagator->add_expr(e);
