@@ -44,7 +44,7 @@ namespace smt {
     }
 
     void qi_queue::setup() {
-        TRACE("qi_cost", tout << "qi_cost: " << m_params.m_qi_cost << "\n";);
+        TRACE(qi_cost, tout << "qi_cost: " << m_params.m_qi_cost << "\n";);
         if (!m_parser.parse_string(m_params.m_qi_cost.c_str(), m_cost_function)) {
             // it is not reasonable to abort here during the creation of smt::context just because an invalid option was provided.
             // throw default_exception("invalid cost function %s", m_params.m_qi_cost.c_str());
@@ -113,7 +113,7 @@ namespace smt {
         m_vals[SCOPE]              = static_cast<float>(m_context.get_scope_level());
         m_vals[NESTED_QUANTIFIERS] = static_cast<float>(stat->get_num_nested_quantifiers());
         m_vals[CS_FACTOR]          = static_cast<float>(stat->get_case_split_factor());
-        TRACE("qi_queue_detail", for (unsigned i = 0; i < m_vals.size(); i++) { tout << m_vals[i] << " "; } tout << "\n";);
+        TRACE(qi_queue_detail, for (unsigned i = 0; i < m_vals.size(); i++) { tout << m_vals[i] << " "; } tout << "\n";);
         return stat;
     }
 
@@ -136,14 +136,14 @@ namespace smt {
     void qi_queue::insert(fingerprint * f, app * pat, unsigned generation, unsigned min_top_generation, unsigned max_top_generation) {
         quantifier * q         = static_cast<quantifier*>(f->get_data());
         float cost             = get_cost(q, pat, generation, min_top_generation, max_top_generation);
-        TRACE("qi_queue_detail",
+        TRACE(qi_queue_detail,
               tout << "new instance of " << q->get_qid() << ", weight " << q->get_weight()
               << ", generation: " << generation << ", scope_level: " << m_context.get_scope_level() << ", cost: " << cost << "\n";
               for (unsigned i = 0; i < f->get_num_args(); i++) {
                   tout << "#" << f->get_arg(i)->get_expr_id() << " d:" << f->get_arg(i)->get_expr()->get_depth() << " ";
               }
               tout << "\n";);
-        TRACE("new_entries_bug", tout << "[qi:insert]\n";);
+        TRACE(new_entries_bug, tout << "[qi:insert]\n";);
         m_new_entries.push_back(entry(f, cost, generation));
     }
 
@@ -153,6 +153,11 @@ namespace smt {
             if (m_context.get_cancel_flag()) {
                 break;
             }
+            if (m_stats.m_num_instances > m_params.m_qi_max_instances) {
+                m_context.set_reason_unknown("maximum number of quantifier instances was reached");
+                m_context.set_internal_completed();
+                break;
+            }
             fingerprint * f    = curr.m_qb;
             quantifier * qa    = static_cast<quantifier*>(f->get_data());
 
@@ -161,11 +166,11 @@ namespace smt {
             }
             else if (m_params.m_qi_promote_unsat && m_checker.is_unsat(qa->get_expr(), f->get_num_args(), f->get_args())) {
                 // do not delay instances that produce a conflict.
-                TRACE("qi_unsat", tout << "promoting instance that produces a conflict\n" << mk_pp(qa, m) << "\n";);
+                TRACE(qi_unsat, tout << "promoting instance that produces a conflict\n" << mk_pp(qa, m) << "\n";);
                 instantiate(curr);
             }
             else {
-                TRACE("qi_queue", tout << "delaying quantifier instantiation... " << f << "\n" << mk_pp(qa, m) << "\ncost: " << curr.m_cost << "\n";);
+                TRACE(qi_queue, tout << "delaying quantifier instantiation... " << f << "\n" << mk_pp(qa, m) << "\ncost: " << curr.m_cost << "\n";);
                 m_delayed_entries.push_back(curr);
             }
 
@@ -178,13 +183,12 @@ namespace smt {
             }
         }
         m_new_entries.reset();
-        TRACE("new_entries_bug", tout << "[qi:instantiate]\n";);
+        TRACE(new_entries_bug, tout << "[qi:instantiate]\n";);
     }
 
     void qi_queue::display_instance_profile(fingerprint * f, quantifier * q, unsigned num_bindings, enode * const * bindings, unsigned proof_id, unsigned generation) {
         if (m.has_trace_stream()) {
-            m.trace_stream() << "[instance] ";
-            m.trace_stream() << static_cast<void*>(f);
+            m.trace_stream() << "[instance] " << f->get_data_hash();
             if (m.proofs_enabled())
                 m.trace_stream() << " #" << proof_id;
             m.trace_stream() << " ; " << generation;
@@ -204,22 +208,22 @@ namespace smt {
 
         ent.m_instantiated = true;
                 
-        TRACE("qi_queue_profile", tout << q->get_qid() << ", gen: " << generation << " " << *f << " cost: " << ent.m_cost << "\n";);
+        TRACE(qi_queue_profile, tout << q->get_qid() << ", gen: " << generation << " " << *f << " cost: " << ent.m_cost << "\n";);
 
         q::quantifier_stat * stat = m_qm.get_stat(q);
 
         if (m_checker.is_sat(q->get_expr(), num_bindings, bindings)) {
-            TRACE("checker", tout << "instance already satisfied\n";);
+            TRACE(checker, tout << "instance already satisfied\n";);
             // we log the "dummy" instantiations separately from "instance"
-            STRACE("dummy", tout << "### " << static_cast<void*>(f) <<", " << q->get_qid() << "\n";);
-            STRACE("dummy", tout << "Instance already satisfied (dummy)\n";);
+            STRACE(dummy, tout << "### " << static_cast<void*>(f) <<", " << q->get_qid() << "\n";);
+            STRACE(dummy, tout << "Instance already satisfied (dummy)\n";);
             // a dummy instantiation is still an instantiation.
             // in this way smt.qi.profile=true coincides with the axiom profiler
             stat->inc_num_instances_checker_sat();
             return;
         }
 
-        STRACE("instance", tout << "### " << static_cast<void*>(f) <<", " << q->get_qid()  << "\n";);
+        STRACE(instance, tout << "### " << static_cast<void*>(f) <<", " << q->get_qid()  << "\n";);
 
         auto* ebindings = m_subst(q, num_bindings);
         for (unsigned i = 0; i < num_bindings; ++i)
@@ -227,14 +231,14 @@ namespace smt {
         expr_ref instance = m_subst();
 
 
-        TRACE("qi_queue", tout << "new instance:\n" << mk_pp(instance, m) << "\n";);
+        TRACE(qi_queue, tout << "new instance:\n" << mk_pp(instance, m) << "\n";);
         expr_ref  s_instance(m);
         proof_ref pr(m);
         m_context.get_rewriter()(instance, s_instance, pr);
 
-        TRACE("qi_queue_bug", tout << "new instance after simplification:\n" << s_instance << "\n";);
+        TRACE(qi_queue_bug, tout << "new instance after simplification:\n" << s_instance << "\n";);
         if (m.is_true(s_instance)) {
-            STRACE("instance", tout <<  "Instance reduced to true\n";);
+            STRACE(instance, tout <<  "Instance reduced to true\n";);
             stat -> inc_num_instances_simplify_true();
             if (m.has_trace_stream()) {
                 display_instance_profile(f, q, num_bindings, bindings, pr ? pr->get_id() : 0, generation);
@@ -254,11 +258,16 @@ namespace smt {
         std::cout << instance << "\n";
 #endif
    
-        TRACE("qi_queue", tout << "simplified instance:\n" << s_instance << "\n";);
+        TRACE(qi_queue, tout << "simplified instance:\n" << s_instance << "\n";);
         stat->inc_num_instances();
         if (stat->get_num_instances() % m_params.m_qi_profile_freq == 0) {
             m_qm.display_stats(verbose_stream(), q);
         }
+
+        if (m_on_binding && !m_on_binding(q, instance)) {
+            verbose_stream() << "qi_queue: on_binding returned false, skipping instance.\n";
+            return;
+        }
         expr_ref lemma(m);
         if (m.is_or(s_instance)) {
             ptr_vector<expr> args;
@@ -317,7 +326,7 @@ namespace smt {
             pr1 = m.mk_app(symbol("inst"), args.size(), args.data(), m.mk_proof_sort());
             m_instances.push_back(pr1);            
         }
-        TRACE("qi_queue", tout << mk_pp(lemma, m) << "\n#" << lemma->get_id() << ":=\n" << mk_ll_pp(lemma, m););
+        TRACE(qi_queue, tout << mk_pp(lemma, m) << "\n#" << lemma->get_id() << ":=\n" << mk_ll_pp(lemma, m););
         m_stats.m_num_instances++;
         unsigned gen = get_new_gen(q, generation, ent.m_cost);
         display_instance_profile(f, q, num_bindings, bindings, proof_id, gen);
@@ -341,10 +350,10 @@ namespace smt {
                     }
                 }
                 if (true_child && has_unassigned) {
-                    TRACE("qi_queue_profile_detail", tout << "missed:\n" << mk_ll_pp(s_instance, m) << "\n#" << true_child->get_id() << "\n";);
+                    TRACE(qi_queue_profile_detail, tout << "missed:\n" << mk_ll_pp(s_instance, m) << "\n#" << true_child->get_id() << "\n";);
                     num_useless++;
                     if (num_useless % 10 == 0) {
-                        TRACE("qi_queue_profile", tout << "num useless: " << num_useless << "\n";);
+                        TRACE(qi_queue_profile, tout << "num useless: " << num_useless << "\n";);
                     }
                 }
             }
@@ -356,7 +365,7 @@ namespace smt {
     }
 
     void qi_queue::push_scope() {
-        TRACE("new_entries_bug", tout << "[qi:push-scope]\n";);
+        TRACE(new_entries_bug, tout << "[qi:push-scope]\n";);
         m_scopes.push_back(scope());
         SASSERT(m_context.inconsistent() || m_new_entries.empty());
         scope & s = m_scopes.back();
@@ -377,7 +386,7 @@ namespace smt {
         m_instances.shrink(s.m_instances_lim);
         m_new_entries.reset();
         m_scopes.shrink(new_lvl);
-        TRACE("new_entries_bug", tout << "[qi:pop-scope]\n";);
+        TRACE(new_entries_bug, tout << "[qi:pop-scope]\n";);
     }
 
     void qi_queue::reset() {
@@ -393,7 +402,7 @@ namespace smt {
     }
 
     bool qi_queue::final_check_eh() {
-        TRACE("qi_queue", display_delayed_instances_stats(tout); tout << "lazy threshold: " << m_params.m_qi_lazy_threshold
+        TRACE(qi_queue, display_delayed_instances_stats(tout); tout << "lazy threshold: " << m_params.m_qi_lazy_threshold
               << ", scope_level: " << m_context.get_scope_level() << "\n";);
 
         if (m_params.m_qi_conservative_final_check) {
@@ -402,19 +411,19 @@ namespace smt {
             unsigned sz = m_delayed_entries.size();
             for (unsigned i = 0; i < sz; i++) {
                 entry & e       = m_delayed_entries[i];
-                TRACE("qi_queue", tout << e.m_qb << ", cost: " << e.m_cost << ", instantiated: " << e.m_instantiated << "\n";);
+                TRACE(qi_queue, tout << e.m_qb << ", cost: " << e.m_cost << ", instantiated: " << e.m_instantiated << "\n";);
                 if (!e.m_instantiated && e.m_cost <= m_params.m_qi_lazy_threshold && (!init || e.m_cost < min_cost)) {
                     init = true;
                     min_cost = e.m_cost;
                 }
             }
-            TRACE("qi_queue_min_cost", tout << "min_cost: " << min_cost << ", scope_level: " << m_context.get_scope_level() << "\n";);
+            TRACE(qi_queue_min_cost, tout << "min_cost: " << min_cost << ", scope_level: " << m_context.get_scope_level() << "\n";);
             bool result = true;
             for (unsigned i = 0; i < sz; i++) {
                 entry & e       = m_delayed_entries[i];
-                TRACE("qi_queue", tout << e.m_qb << ", cost: " << e.m_cost << " min-cost: " << min_cost << ", instantiated: " << e.m_instantiated << "\n";);
+                TRACE(qi_queue, tout << e.m_qb << ", cost: " << e.m_cost << " min-cost: " << min_cost << ", instantiated: " << e.m_instantiated << "\n";);
                 if (!e.m_instantiated && e.m_cost <= min_cost) {
-                    TRACE("qi_queue",
+                    TRACE(qi_queue,
                           tout << "lazy quantifier instantiation...\n" << mk_pp(static_cast<quantifier*>(e.m_qb->get_data()), m) << "\ncost: " << e.m_cost << "\n";);
                     result             = false;
                     m_instantiated_trail.push_back(i);
@@ -428,9 +437,9 @@ namespace smt {
         bool result = true;
         for (unsigned i = 0; i < m_delayed_entries.size(); i++) {
             entry & e       = m_delayed_entries[i];
-            TRACE("qi_queue", tout << e.m_qb << ", cost: " << e.m_cost << ", instantiated: " << e.m_instantiated << "\n";);
+            TRACE(qi_queue, tout << e.m_qb << ", cost: " << e.m_cost << ", instantiated: " << e.m_instantiated << "\n";);
             if (!e.m_instantiated && e.m_cost <= m_params.m_qi_lazy_threshold)  {
-                TRACE("qi_queue",
+                TRACE(qi_queue,
                       tout << "lazy quantifier instantiation...\n" << mk_pp(static_cast<quantifier*>(e.m_qb->get_data()), m) << "\ncost: " << e.m_cost << "\n";);
                 result             = false;
                 m_instantiated_trail.push_back(i);
