@@ -133,7 +133,7 @@ namespace smt {
         q::quantifier_stat_gen                    m_qstat_gen;
         ptr_vector<quantifier>                 m_quantifiers;
         scoped_ptr<quantifier_manager_plugin>  m_plugin;
-        unsigned                               m_num_instances;
+        unsigned                               m_num_instances = 0;
 
         imp(quantifier_manager & wrapper, context & ctx, smt_params & p, quantifier_manager_plugin * plugin):
             m_wrapper(wrapper),
@@ -142,7 +142,6 @@ namespace smt {
             m_qi_queue(m_wrapper, ctx, p),
             m_qstat_gen(ctx.get_manager(), ctx.get_region()),
             m_plugin(plugin) {
-            m_num_instances = 0;
             m_qi_queue.setup();
         }
 
@@ -212,23 +211,23 @@ namespace smt {
 
             if (pat != nullptr) {
                 if (used_enodes.size() > 0) {
-                    STRACE("causality", tout << "New-Match: "<< static_cast<void*>(f););
-                    STRACE("triggers",  tout <<", Pat: "<< expr_ref(pat, m()););
-                    STRACE("causality", tout <<", Father:";);
+                    STRACE(causality, tout << "New-Match: "<< static_cast<void*>(f););
+                    STRACE(triggers,  tout <<", Pat: "<< expr_ref(pat, m()););
+                    STRACE(causality, tout <<", Father:";);
                 }
                 for (auto n : used_enodes) {
                     enode *orig = std::get<0>(n);
                     enode *substituted = std::get<1>(n);
                     (void) substituted;
                     if (orig == nullptr) {
-                        STRACE("causality", tout << " #" << substituted->get_owner_id(););
+                        STRACE(causality, tout << " #" << substituted->get_owner_id(););
                     }
                     else {
-                        STRACE("causality", tout << " (#" << orig->get_owner_id() << " #" << substituted->get_owner_id() << ")";);
+                        STRACE(causality, tout << " (#" << orig->get_owner_id() << " #" << substituted->get_owner_id() << ")";);
                     }
                 }
                 if (used_enodes.size() > 0) {
-                    STRACE("causality", tout << "\n";);
+                    STRACE(causality, tout << "\n";);
                 }
             }
         }
@@ -241,7 +240,7 @@ namespace smt {
              vector<std::tuple<enode *, enode *>> & used_enodes) {
 
             if (pat == nullptr) {
-                trace_stream() << "[inst-discovered] MBQI " << static_cast<void*>(f) << " #" << q->get_id();
+                trace_stream() << "[inst-discovered] MBQI " << f->get_data_hash() << " #" << q->get_id();
                 for (unsigned i = 0; i < num_bindings; ++i) {
                     trace_stream() << " #" << bindings[num_bindings - i - 1]->get_owner_id();
                 }
@@ -267,7 +266,7 @@ namespace smt {
                 }
 
                 // At this point all relevant equalities for the match are logged.
-                out << "[new-match] " << static_cast<void*>(f) << " #" << q->get_id() << " #" << pat->get_id();
+                out << "[new-match] " << f->get_data_hash() << " #" << q->get_id() << " #" << pat->get_id();
                 for (unsigned i = 0; i < num_bindings; i++) {
                     // I don't want to use mk_pp because it creates expressions for pretty printing.
                     // This nasty side-effect may change the behavior of Z3.
@@ -297,13 +296,11 @@ namespace smt {
                           vector<std::tuple<enode *, enode *>> & used_enodes) {
 
             max_generation = std::max(max_generation, get_generation(q));
-            if (m_num_instances > m_params.m_qi_max_instances) {
-                return false;
-            }
+            
             get_stat(q)->update_max_generation(max_generation);
             fingerprint * f = m_context.add_fingerprint(q, q->get_id(), num_bindings, bindings, def);
             if (f) {
-                if (is_trace_enabled("causality")) {
+                if (is_trace_enabled(TraceTag::causality)) {
                     log_causality(f,pat,used_enodes);
                 }
                 if (has_trace_stream()) {
@@ -313,7 +310,7 @@ namespace smt {
                 m_num_instances++;
             }
 
-            CTRACE("bindings", f != nullptr, 
+            CTRACE(bindings, f != nullptr, 
                   tout << expr_ref(q, m()) << "\n";
                   for (unsigned i = 0; i < num_bindings; ++i) {
                       tout << expr_ref(bindings[i]->get_expr(), m()) << " [r " << bindings[i]->get_root()->get_owner_id() << "] ";
@@ -331,7 +328,7 @@ namespace smt {
             }
             m_qi_queue.init_search_eh();
             m_plugin->init_search_eh();
-            TRACE("smt_params", m_params.display(tout); );
+            TRACE(smt_params, m_params.display(tout); );
         }
 
         void assign_eh(quantifier * q) {
@@ -342,6 +339,10 @@ namespace smt {
             m_plugin->add_eq_eh(n1, n2);
         }
 
+        void register_on_binding(std::function<bool(quantifier*, expr*)>& on_binding) {
+            m_qi_queue.register_on_binding(on_binding);
+        }
+
         void relevant_eh(enode * n) {
             m_plugin->relevant_eh(n);
         }
@@ -496,6 +497,10 @@ namespace smt {
         m_imp->add_eq_eh(n1, n2);
     }
 
+    void quantifier_manager::register_on_binding(std::function<bool(quantifier*, expr*)>& on_binding) {
+        m_imp->register_on_binding(on_binding);
+    }
+
     void quantifier_manager::relevant_eh(enode * n) {
         m_imp->relevant_eh(n);
     }
@@ -639,7 +644,7 @@ namespace smt {
            mbqi.id to be instantiated with MBQI. The default value is the
            empty string, so all quantifiers are instantiated. */
         void add(quantifier * q) override {
-            TRACE("model_finder", tout << "add " << q->get_id() << ": " << q << " " << m_fparams->m_mbqi << " " << mbqi_enabled(q) << "\n";);
+            TRACE(model_finder, tout << "add " << q->get_id() << ": " << q << " " << m_fparams->m_mbqi << " " << mbqi_enabled(q) << "\n";);
             if (m_fparams->m_mbqi && mbqi_enabled(q)) {
                 m_active = true;
                 m_model_finder->register_quantifier(q);
@@ -690,13 +695,13 @@ namespace smt {
                 SASSERT(m.is_pattern(mp));
                 bool unary = (mp->get_num_args() == 1);
                 if (!unary && j >= num_eager_multi_patterns) {
-                    TRACE("quantifier", tout << "delaying (too many multipatterns):\n" << mk_ismt2_pp(mp, m) << "\n"
+                    TRACE(quantifier, tout << "delaying (too many multipatterns):\n" << mk_ismt2_pp(mp, m) << "\n"
                           << "j: " << j << " unary: " << unary << " m_params.m_qi_max_eager_multipatterns: " << m_fparams->m_qi_max_eager_multipatterns
                           << " num_eager_multi_patterns: " << num_eager_multi_patterns << "\n";);
                     m_lazy_mam->add_pattern(q, mp);
                 }
                 else {
-                    TRACE("quantifier", tout << "adding:\n" << expr_ref(mp, m) << "\n";);
+                    TRACE(quantifier, tout << "adding:\n" << expr_ref(mp, m) << "\n";);
                     m_mam->add_pattern(q, mp);
                 }
                 if (!unary)
@@ -729,7 +734,7 @@ namespace smt {
                 m_model_finder->restart_eh();
                 m_model_checker->restart_eh();
             }
-            TRACE("mam_stats", m_mam->display(tout););
+            TRACE(mam_stats, m_mam->display(tout););
         }
 
         bool is_shared(enode * n) const override {
