@@ -24,7 +24,7 @@ Revision History:
 #include "smt/theory_recfun.h"
 
 
-#define TRACEFN(x) TRACE("recfun", tout << x << '\n';)
+#define TRACEFN(x) TRACE(recfun, tout << x << '\n';)
 
 namespace smt {
 
@@ -43,32 +43,32 @@ namespace smt {
 
     char const * theory_recfun::get_name() const { return "recfun"; }
 
-    theory* theory_recfun::mk_fresh(context* new_ctx) {
+    theory* theory_recfun::mk_fresh(context* new_ctx) {        
         return alloc(theory_recfun, *new_ctx);
     }
 
     bool theory_recfun::internalize_atom(app * atom, bool gate_ctx) {
+        TRACE(recfun, tout << mk_pp(atom, m) << " " << u().has_defs() << "\n");
         if (!u().has_defs()) {
+//            if (u().is_defined(atom)) 
+//                throw default_exception("recursive atom definition is out of scope");
             return false;
         }
-        for (expr * arg : *atom) {
+        for (expr * arg : *atom) 
             ctx.internalize(arg, false);
-        }
-        if (!ctx.e_internalized(atom)) {
-            ctx.mk_enode(atom, false, true, false);
-        }
-        if (!ctx.b_internalized(atom)) {
-            bool_var v = ctx.mk_bool_var(atom);
-            ctx.set_var_theory(v, get_id());
-        }
-        if (!ctx.relevancy() && u().is_defined(atom)) {
+        if (!ctx.e_internalized(atom)) 
+            ctx.mk_enode(atom, false, true, true);
+        if (!ctx.b_internalized(atom)) 
+            ctx.set_var_theory(ctx.mk_bool_var(atom), get_id());
+        if (!ctx.relevancy() && u().is_defined(atom)) 
             push_case_expand(atom);
-        }
         return true;
     }
 
     bool theory_recfun::internalize_term(app * term) {
         if (!u().has_defs()) {
+//            if (u().is_defined(term)) 
+//                throw default_exception("recursive term definition is out of scope");
             return false;
         }
         for (expr* e : *term) {
@@ -102,9 +102,8 @@ namespace smt {
     void theory_recfun::relevant_eh(app * n) {
         SASSERT(ctx.relevancy());
         // TRACEFN("relevant_eh: (defined) " <<  u().is_defined(n) << " " << mk_pp(n, m));        
-        if (u().is_defined(n) && u().has_defs()) {
+        if (u().is_defined(n) && u().has_defs()) 
             push_case_expand(n);
-        }
     }
 
     void theory_recfun::push_scope_eh() {
@@ -214,7 +213,7 @@ namespace smt {
     void theory_recfun::assign_eh(bool_var v, bool is_true) {
         expr* e = ctx.bool_var2expr(v);
         if (is_true && u().is_case_pred(e)) {
-            TRACEFN("assign_case_pred_true " << mk_pp(e, m));
+            TRACEFN("assign_case_pred_true " << v << " " << mk_pp(e, m));
             // body-expand
             push_body_expand(e);
         }
@@ -226,7 +225,6 @@ namespace smt {
         recfun::vars const & vars,
         expr_ref_vector const & args,
         expr * e) {
-        SASSERT(is_standard_order(vars));
         var_subst subst(m, true);
         expr_ref new_body = subst(e, args);
         ctx.get_rewriter()(new_body); // simplify
@@ -246,17 +244,23 @@ namespace smt {
 
     literal theory_recfun::mk_eq_lit(expr* l, expr* r) {
         literal lit;
-        if (m.is_true(r) || m.is_false(r)) {
-            std::swap(l, r);
-        }
-        if (m.is_true(l)) {
-            lit = mk_literal(r);
-        }
-        else if (m.is_false(l)) {
-            lit = ~mk_literal(r);
+        if (has_quantifiers(l) || has_quantifiers(r)) {
+            expr_ref eq1(m.mk_eq(l, r), m);
+            expr_ref fn(m.mk_fresh_const("rec-eq", m.mk_bool_sort()), m);
+            expr_ref eq(m.mk_eq(fn, eq1), m);
+            ctx.add_asserted(eq);
+            ctx.internalize_assertions();
+            lit = mk_literal(fn);
         }
         else {
-            lit = mk_eq(l, r, false);        
+            if (m.is_true(r) || m.is_false(r))
+                std::swap(l, r);
+            if (m.is_true(l))
+                lit = mk_literal(r);
+            else if (m.is_false(l))
+                lit = ~mk_literal(r);
+            else
+                lit = mk_eq(l, r, false);
         }
         ctx.mark_as_relevant(lit);
         return lit;
@@ -282,14 +286,12 @@ namespace smt {
         auto & vars = e.m_def->get_vars();
         expr_ref lhs(e.m_lhs, m);
         unsigned depth = get_depth(e.m_lhs);
-        expr_ref rhs(apply_args(depth, vars, e.m_args, e.m_def->get_rhs()), m);	
+        expr_ref rhs(apply_args(depth, vars, e.m_args, e.m_def->get_rhs()), m);
         literal lit = mk_eq_lit(lhs, rhs);
         std::function<literal(void)> fn = [&]() { return lit; };
         scoped_trace_stream _tr(*this, fn);
         ctx.mk_th_axiom(get_id(), 1, &lit);
         TRACEFN("macro expansion yields " << pp_lit(ctx, lit));
-	    if (has_quantifiers(rhs))
-	        throw default_exception("quantified formulas in recursive functions are not supported");
     }
 
     /**
@@ -339,6 +341,7 @@ namespace smt {
             activate_guard(pred_applied, guards);
         }
 
+        TRACEFN("assert cases " << preds);
         // the disjunction of branches is asserted
         // to close the available cases. 
 
@@ -373,10 +376,16 @@ namespace smt {
         recfun::def & d = *e.m_cdef->get_def();
         auto & vars = d.get_vars();
         auto & args = e.m_args;
-        SASSERT(is_standard_order(vars));
         unsigned depth = get_depth(e.m_pred);
         expr_ref lhs(u().mk_fun_defined(d, args), m);
         expr_ref rhs = apply_args(depth, vars, args, e.m_cdef->get_rhs());
+        if (has_quantifiers(rhs)) {
+            expr_ref fn(m.mk_fresh_const("rec-eq", m.mk_bool_sort()), m);
+            expr_ref eq(m.mk_eq(fn, rhs), m);
+            ctx.assert_expr(eq);
+            ctx.internalize_assertions();
+            rhs = fn;
+        }
         literal_vector clause;
         for (auto & g : e.m_cdef->get_guards()) {
             expr_ref guard = apply_args(depth, vars, args, g);
@@ -394,8 +403,6 @@ namespace smt {
         std::function<literal_vector(void)> fn = [&]() { return clause; };
         scoped_trace_stream _tr(*this, fn);
         ctx.mk_th_axiom(get_id(), clause);
-        if (has_quantifiers(rhs))
-            throw default_exception("quantified formulas in recursive functions are not supported");
     }
     
     final_check_status theory_recfun::final_check_eh() {
@@ -408,7 +415,7 @@ namespace smt {
     }
 
     void theory_recfun::add_theory_assumptions(expr_ref_vector & assumptions) {
-        if (u().has_defs() || !m_disabled_guards.empty()) {
+        if (u().has_rec_defs() || !m_disabled_guards.empty()) {
             app_ref dlimit = m_util.mk_num_rounds_pred(m_num_rounds);
             TRACEFN("add_theory_assumption " << dlimit);
             assumptions.push_back(dlimit);
@@ -457,6 +464,15 @@ namespace smt {
         return found;
     }
 
+    /**
+     * n is an argument of p, if p is a function definition or case predicate,
+     * then there is no reason for the solver to enforce that equality on n is 
+     * fully determined. It is a beta-redex with respect to expanding p.
+     */
+    bool theory_recfun::is_beta_redex(enode* p, enode* n) const {
+        return is_defined(p) || is_case_pred(p);
+    }
+
     void theory_recfun::display(std::ostream & out) const {
         out << "recfun\n";
         out << "disabled guards:\n" << m_disabled_guards << "\n";
