@@ -50,15 +50,19 @@ void theory_user_propagator::add_expr(expr* term, bool ensure_enode) {
     expr_ref r(m);
     expr* e = term;
     ctx.get_rewriter()(e, r);
-    TRACE("user_propagate", tout << "add " << mk_bounded_pp(e, m) << "\n");
-    if (r != e) {
+    TRACE(user_propagate, tout << "add " << mk_bounded_pp(e, m) << "\n");
+    if (!is_ground(r)) {
+        if (m_add_expr_fresh.contains(term))
+            return;
+        m_add_expr_fresh.insert(term);
+        ctx.push_trail(insert_obj_trail(m_add_expr_fresh, term));
         r = m.mk_fresh_const("aux-expr", e->get_sort());
         expr_ref eq(m.mk_eq(r, e), m);
         ctx.assert_expr(eq);
         ctx.internalize_assertions();
-        e = r;
         ctx.mark_as_relevant(eq.get());
     }
+    e = r;
     enode* n = ensure_enode ? this->ensure_enode(e) : ctx.get_enode(e);
     if (is_attached_to_var(n))
         return;
@@ -85,7 +89,7 @@ bool theory_user_propagator::propagate_cb(
     unsigned num_fixed, expr* const* fixed_ids, 
     unsigned num_eqs, expr* const* eq_lhs, expr* const* eq_rhs, 
     expr* conseq) {
-    CTRACE("user_propagate", ctx.lit_internalized(conseq) && ctx.get_assignment(ctx.get_literal(conseq)) == l_true,
+    CTRACE(user_propagate, ctx.lit_internalized(conseq) && ctx.get_assignment(ctx.get_literal(conseq)) == l_true,
            ctx.display(tout << "redundant consequence: " << mk_pp(conseq, m) << "\n"));
 
     expr_ref _conseq(conseq, m);
@@ -106,6 +110,15 @@ void theory_user_propagator::register_cb(expr* e) {
         add_expr(e, true);
 }
 
+void theory_user_propagator::register_on_binding(user_propagator::binding_eh_t& binding_eh) {
+    std::function<bool(quantifier* q, expr* inst)> on_binding = 
+        [this, binding_eh](quantifier* q, expr* inst) {
+            return binding_eh(m_user_context, this, q, inst);
+        };    
+    ctx.register_on_binding(on_binding);
+
+}
+
 bool theory_user_propagator::next_split_cb(expr* e, unsigned idx, lbool phase) {
     if (e == nullptr) { // clear
         m_next_split_var = nullptr;
@@ -156,9 +169,9 @@ final_check_status theory_user_propagator::final_check_eh() {
     catch (...) {
         throw default_exception("Exception thrown in \"final\"-callback");
     }
-    CTRACE("user_propagate", can_propagate(), tout << "can propagate\n");
+    CTRACE(user_propagate, can_propagate(), tout << "can propagate\n");
     propagate();
-    CTRACE("user_propagate", ctx.inconsistent(), tout << "inconsistent\n");
+    CTRACE(user_propagate, ctx.inconsistent(), tout << "inconsistent\n");
     // check if it became inconsistent or something new was propagated/registered
     bool done = (sz1 == m_prop.size()) && (sz2 == get_num_vars()) && !ctx.inconsistent();
     return done ? FC_DONE : FC_CONTINUE;
@@ -309,7 +322,7 @@ void theory_user_propagator::propagate_consequence(prop_info const& prop) {
     DEBUG_CODE(for (expr* e : prop.m_ids) VERIFY(m_fixed.contains(expr2var(e))););
     DEBUG_CODE(for (literal lit : m_lits) VERIFY(ctx.get_assignment(lit) == l_true););
     
-    TRACE("user_propagate", tout << "propagating #" << prop.m_conseq->get_id() << ": " << prop.m_conseq << "\n";
+    TRACE(user_propagate, tout << "propagating #" << prop.m_conseq->get_id() << ": " << prop.m_conseq << "\n";
           for (auto const& [a,b] : m_eqs) tout << enode_pp(a, ctx) << " == " << enode_pp(b, ctx) << "\n";
           for (expr* e : prop.m_ids) tout << mk_pp(e, m) << "\n";
           for (literal lit : m_lits) tout << lit << "\n");
@@ -339,24 +352,22 @@ void theory_user_propagator::propagate_consequence(prop_info const& prop) {
         ctx.mark_as_relevant(lit);
 
         m_lits.push_back(lit);
-        if (ctx.get_fparams().m_up_persist_clauses)
-            ctx.mk_th_axiom(get_id(), m_lits);
-        else
-            ctx.mk_th_lemma(get_id(), m_lits);
 
         if (ctx.get_fparams().m_up_persist_clauses) {
-            ctx.mk_th_axiom(get_id(), m_lits);
             expr_ref_vector clause(m);
-            for (auto lit : m_lits)
-                clause.push_back(ctx.literal2expr(lit));
+            for (auto l : m_lits)
+                clause.push_back(ctx.literal2expr(l));
             m_clauses_to_replay.push_back(clause);
-            if (m_replay_qhead + 1 < m_clauses_to_replay.size()) 
+            if (m_replay_qhead + 1 < m_clauses_to_replay.size())
                 std::swap(m_clauses_to_replay[m_replay_qhead], m_clauses_to_replay[m_clauses_to_replay.size()-1]);
             ctx.push_trail(value_trail<unsigned>(m_replay_qhead));
             ++m_replay_qhead;
+            ctx.mk_th_axiom(get_id(), m_lits);
         }
+        else
+            ctx.mk_th_lemma(get_id(), m_lits);
     }
-    TRACE("user_propagate", ctx.display(tout););
+    TRACE(user_propagate, ctx.display(tout););
     
 }
 
@@ -368,7 +379,7 @@ void theory_user_propagator::propagate_new_fixed(prop_info const& prop) {
 void theory_user_propagator::propagate() {
     if (m_qhead == m_prop.size() && m_to_add_qhead == m_to_add.size() && m_replay_qhead == m_clauses_to_replay.size())
         return;
-    TRACE("user_propagate", tout << "propagating queue head: " << m_qhead << " prop queue: " << m_prop.size() << "\n");
+    TRACE(user_propagate, tout << "propagating queue head: " << m_qhead << " prop queue: " << m_prop.size() << "\n");
     force_push();
 
     unsigned qhead = m_replay_qhead;
