@@ -18,7 +18,8 @@ Notes:
 --*/
 #include "tactic/aig/aig.h"
 #include "tactic/goal.h"
-#include "ast/ast_smt2_pp.h"
+#include "ast/ast_ll_pp.h"
+#include "ast/ast_util.h"
 
 #define USE_TWO_LEVEL_RULES
 #define FIRST_NODE_ID (UINT_MAX/2)
@@ -49,7 +50,6 @@ struct aig {
     unsigned m_ref_count;
     aig_lit  m_children[2];
     unsigned m_mark:1;
-    aig() {}
 };
 
 #if Z3DEBUG
@@ -144,7 +144,7 @@ struct aig_manager::imp {
     }
 
     void delete_node(aig * n) {
-        TRACE("aig_lit_count", tout << "deleting: "; display_ref(tout, n); tout << "\n";);
+        TRACE(aig_lit_count, tout << "deleting: "; display_ref(tout, n); tout << "\n";);
         SASSERT(m_num_aigs > 0);
         m_num_aigs--;
         if (is_var(n)) {
@@ -431,13 +431,8 @@ struct aig_manager::imp {
         expr2aig(imp & _m):m(_m) {}
         
         ~expr2aig() {
-            obj_map<expr, aig_lit>::iterator it  = m_cache.begin();
-            obj_map<expr, aig_lit>::iterator end = m_cache.end();
-            for (; it != end; ++it) {
-                TRACE("expr2aig", tout << "dec-ref: "; m.display_ref(tout, it->m_value); 
-                      tout << " ref-count: " << ref_count(it->m_value) << "\n";);
-                m.dec_ref(it->m_value);
-            }
+            for (auto& [k,v] : m_cache) 
+                m.dec_ref(v);
             restore_result_stack(0);
         }
         
@@ -447,7 +442,7 @@ struct aig_manager::imp {
         }
 
         void cache_result(expr * t, aig_lit const & r) {
-            TRACE("expr2aig", tout << "caching:\n" << mk_ismt2_pp(t, m.m()) << "\n---> "; m.display_ref(tout, r); tout << "\n";); 
+            TRACE(expr2aig, tout << "caching:\n" << mk_bounded_pp(t, m.m()) << "\n---> "; m.display_ref(tout, r); tout << "\n";); 
             SASSERT(!m_cache.contains(t));
             m.inc_ref(r);
             m_cache.insert(t, r);
@@ -559,7 +554,7 @@ struct aig_manager::imp {
             aig_lit r;
             switch (num) {
             case 0:
-                r = m.m_true;
+                r = m.m_false;
                 break;
             case 1:
                 r = m_result_stack[spos];
@@ -779,7 +774,7 @@ struct aig_manager::imp {
                 return n->m_id == 0 ? ast_mng.mk_true() : m.var2expr(n);
             }
             else {
-                CTRACE("aig2expr", !is_cached(n), tout << "invalid get_cached for "; m.display_ref(tout, n); tout << "\n";);
+                CTRACE(aig2expr, !is_cached(n), tout << "invalid get_cached for "; m.display_ref(tout, n); tout << "\n";);
                 SASSERT(is_cached(n));
                 return m_cache.get(to_idx(n));
             }
@@ -872,7 +867,7 @@ struct aig_manager::imp {
             }
             expr * r = ast_mng.mk_not(ast_mng.mk_or(m_and_children.size(), m_and_children.data()));
             cache_result(n, r);
-            TRACE("aig2expr", tout << "caching AND "; m.display_ref(tout, n); tout << "\n";);
+            TRACE(aig2expr, tout << "caching AND "; m.display_ref(tout, n); tout << "\n";);
         }
 
         void mk_ite(aig * n) {
@@ -890,7 +885,7 @@ struct aig_manager::imp {
                 r = ast_mng.mk_ite(get_cached(c), get_cached(t), get_cached(e));
             }
             cache_result(n, r);
-            TRACE("aig2expr", tout << "caching ITE/IFF "; m.display_ref(tout, n); tout << "\n";);
+            TRACE(aig2expr, tout << "caching ITE/IFF "; m.display_ref(tout, n); tout << "\n";);
         }
 
         /**
@@ -940,7 +935,7 @@ struct aig_manager::imp {
                 switch (fr.m_kind){
                 case AIG_AUX_AND:
                     // do nothing
-                    TRACE("aig2expr", tout << "skipping aux AND "; m.display_ref(tout, n); tout << "\n";);
+                    TRACE(aig2expr, tout << "skipping aux AND "; m.display_ref(tout, n); tout << "\n";);
                     break;
                 case AIG_AND:
                     mk_and(n);
@@ -1009,33 +1004,34 @@ struct aig_manager::imp {
                 r = invert(r);
         }
 
-        void operator()(aig_lit const & l, expr_ref & r) {
-            naive(l, r);
-        }
-
-        void operator()(aig_lit const & l, goal & g) {
-            g.reset();
+        void not_naive(aig_lit const& l, expr_ref & r) {
             sbuffer<aig_lit> roots;
+            expr_ref_vector rs(r.m());
             roots.push_back(l);
             while (!roots.empty()) {
                 aig_lit n = roots.back();
                 roots.pop_back();
                 if (n.is_inverted()) {
-                    g.assert_expr(invert(process_root(n.ptr())), nullptr, nullptr);
+                    rs.push_back(invert(process_root(n.ptr())));
                     continue;
                 }
                 aig * p = n.ptr();
                 if (m.is_ite(p)) {
-                    g.assert_expr(process_root(p), nullptr, nullptr);
+                    rs.push_back(process_root(p));
                     continue;
                 }
                 if (is_var(p)) {
-                    g.assert_expr(m.var2expr(p), nullptr, nullptr);
+                    rs.push_back(m.var2expr(p));
                     continue;
                 }
                 roots.push_back(left(p));
                 roots.push_back(right(p));
             }
+            r = ::mk_and(rs);
+        }
+
+        void operator()(aig_lit const & l, expr_ref & r) {            
+            not_naive(l, r);
         }
 
     };
@@ -1140,7 +1136,7 @@ struct aig_manager::imp {
             aig_lit a = left(left(n));
             aig_lit b = right(left(n));
             aig_lit c = right(n);
-            TRACE("max_sharing", 
+            TRACE(max_sharing, 
                   tout << "trying (and "; m.display_ref(tout, a); 
                   tout << " (and ";       m.display_ref(tout, b); 
                   tout << " ";            m.display_ref(tout, c);
@@ -1153,12 +1149,12 @@ struct aig_manager::imp {
                     r.invert();
                 save_result(o, r);
                 m.dec_ref(bc);
-                TRACE("max_sharing", tout << "improved:\n"; m.display(tout, o); tout << "---->\n"; m.display(tout, r););
+                TRACE(max_sharing, tout << "improved:\n"; m.display(tout, o); tout << "---->\n"; m.display(tout, r););
                 return true;
             }
             m.dec_ref(bc);
             
-            TRACE("max_sharing", 
+            TRACE(max_sharing, 
                   tout << "trying (and "; m.display_ref(tout, a); 
                   tout << " (and ";       m.display_ref(tout, c); 
                   tout << " ";            m.display_ref(tout, b);
@@ -1171,7 +1167,7 @@ struct aig_manager::imp {
                     r.invert();
                 save_result(o, r);
                 m.dec_ref(ac);
-                TRACE("max_sharing", tout << "improved:\n"; m.display(tout, o); tout << "---->\n"; m.display(tout, r););
+                TRACE(max_sharing, tout << "improved:\n"; m.display(tout, o); tout << "---->\n"; m.display(tout, r););
                 return true;
             }
             m.dec_ref(ac);
@@ -1185,7 +1181,7 @@ struct aig_manager::imp {
             aig_lit a = left(n);
             aig_lit b = left(right(n));
             aig_lit c = right(right(n));
-            TRACE("max_sharing", 
+            TRACE(max_sharing, 
                   tout << "trying (and (and "; m.display_ref(tout, a); 
                   tout << " ";                 m.display_ref(tout, b); 
                   tout << ") ";                m.display_ref(tout, c);
@@ -1198,13 +1194,13 @@ struct aig_manager::imp {
                     r.invert();
                 save_result(o, r);
                 m.dec_ref(ab);
-                TRACE("max_sharing", tout << "improved:\n"; m.display(tout, o); tout << "---->\n"; m.display(tout, r););
+                TRACE(max_sharing, tout << "improved:\n"; m.display(tout, o); tout << "---->\n"; m.display(tout, r););
                 return true;
             }
             m.dec_ref(ab);
             
             aig_lit ac = m.mk_and(a, c);
-            TRACE("max_sharing", 
+            TRACE(max_sharing, 
                   tout << "trying (and (and "; m.display_ref(tout, a); 
                   tout << " ";                 m.display_ref(tout, c); 
                   tout << ") ";                m.display_ref(tout, b);
@@ -1216,7 +1212,7 @@ struct aig_manager::imp {
                     r.invert();
                 save_result(o, r);
                 m.dec_ref(ac);
-                TRACE("max_sharing", tout << "improved:\n"; m.display(tout, o); tout << "---->\n"; m.display(tout, r););
+                TRACE(max_sharing, tout << "improved:\n"; m.display(tout, o); tout << "---->\n"; m.display(tout, r););
                 return true;
             }
             m.dec_ref(ac);
@@ -1270,7 +1266,7 @@ struct aig_manager::imp {
             start:
                 frame & fr = m_frame_stack.back();
                 aig * n    = fr.m_node;
-                TRACE("max_sharing", tout << "processing "; m.display_ref(tout, n); tout << " idx: " << fr.m_idx << "\n";);
+                TRACE(max_sharing, tout << "processing "; m.display_ref(tout, n); tout << " idx: " << fr.m_idx << "\n";);
                 switch (fr.m_idx) {
                 case 0: 
                     fr.m_idx++;
@@ -1293,7 +1289,7 @@ struct aig_manager::imp {
             process(p.ptr());
             SASSERT(m_result_stack.size() == 1);
             aig_lit r = m_result_stack.back();
-            TRACE("max_sharing", tout << "r.is_null(): " << r.is_null() << "\n";);
+            TRACE(max_sharing, tout << "r.is_null(): " << r.is_null() << "\n";);
             SASSERT(r.is_null() || ref_count(r) >= 1);
             reset_cache();
             if (r.is_null()) {
@@ -1304,7 +1300,7 @@ struct aig_manager::imp {
                 r.invert();
             }
             m_result_stack.pop_back();
-            TRACE("max_sharing", tout << "result:\n"; m.display(tout, r););
+            TRACE(max_sharing, tout << "result:\n"; m.display(tout, r););
             m.dec_ref_result(r);
             return r;
         }
@@ -1352,7 +1348,7 @@ public:
 
     aig_lit mk_and(aig_lit r1, aig_lit r2) {
         aig_lit r = mk_node(r1, r2);
-        TRACE("mk_and_bug", 
+        TRACE(mk_and_bug, 
               display(tout, r1);
               tout << "AND\n";
               display(tout, r2);
@@ -1534,18 +1530,14 @@ public:
             }
             SASSERT(ref_count(r) >= 1);
         }
-    catch (const aig_exception & ex) {
-        dec_ref(r);
-        throw ex;
-    }
+        catch (const aig_exception & ex) {
+            dec_ref(r);
+            throw ex;
+        }
         dec_ref_result(r);
         return r;
     }
 
-    void to_formula(aig_lit const & r, goal & g) {
-        aig2expr proc(*this);
-        proc(r, g);
-    }
     
     void to_formula(aig_lit const & r, expr_ref & result) {
         aig2expr proc(*this);
@@ -1581,7 +1573,7 @@ public:
             qhead++;
             display_ref(out, n); out << ": ";
             if (is_var(n)) {
-                out << mk_ismt2_pp(m_var2exprs[n->m_id], m()) << "\n";
+                out << mk_bounded_pp(m_var2exprs[n->m_id], m()) << "\n";
             }
             else {
                 display_ref(out, n->m_children[0]);
@@ -1607,7 +1599,7 @@ public:
         if (r.is_inverted())
             out << "(not ";
         if (is_var(r)) {
-            out << mk_ismt2_pp(var2expr(r.ptr()), m());
+            out << mk_bounded_pp(var2expr(r.ptr()), m());
         }
         else {
             out << "aig" << to_idx(r.ptr());
@@ -1738,11 +1730,6 @@ void aig_manager::max_sharing(aig_ref & r) {
     r = aig_ref(*this, m_imp->max_sharing(aig_lit(r)));
 }
 
-void aig_manager::to_formula(aig_ref const & r, goal & g) {
-    SASSERT(!g.proofs_enabled());
-    SASSERT(!g.unsat_core_enabled());
-    return m_imp->to_formula(aig_lit(r), g);
-}
 
 void aig_manager::to_formula(aig_ref const & r, expr_ref & res) {
     return m_imp->to_formula(aig_lit(r), res);
