@@ -86,7 +86,7 @@ class lia2pb_tactic : public tactic {
             return is_target_core(n, u) && u > rational(1);
         }
         
-        struct failed {};
+        struct failed : public std::exception {};
 
         struct visitor {
             imp & m_owner;
@@ -94,7 +94,7 @@ class lia2pb_tactic : public tactic {
             visitor(imp & o):m_owner(o) {}
             
             void throw_failed(expr * n) {
-                TRACE("lia2pb", tout << "Failed at:\n" << mk_ismt2_pp(n, m_owner.m) << "\n";);
+                TRACE(lia2pb, tout << "Failed at:\n" << mk_ismt2_pp(n, m_owner.m) << "\n";);
                 throw failed();
             }
             
@@ -200,7 +200,7 @@ class lia2pb_tactic : public tactic {
             for (unsigned i = 0; i < g->size(); ++i)
                 m_bm(g->form(i), g->dep(i), g->pr(i));
             
-            TRACE("lia2pb", m_bm.display(tout););
+            TRACE(lia2pb, m_bm.display(tout););
             
             // check if there is some variable to be converted
             if (!has_target()) {
@@ -256,7 +256,7 @@ class lia2pb_tactic : public tactic {
                         if (dep != nullptr)
                             m_new_deps.push_back(dep);
                     }
-                    TRACE("lia2pb", tout << mk_ismt2_pp(x, m) << " -> " << dep << "\n";);
+                    TRACE(lia2pb, tout << mk_ismt2_pp(x, m) << " -> " << dep << "\n";);
                     subst.insert(x, def, nullptr, dep);
                     if (m_produce_models) {
                         gmc->add(x, def);
@@ -325,7 +325,7 @@ public:
             (*m_imp)(in, result);
         }
         catch (rewriter_exception & ex) {
-            throw tactic_exception(ex.msg());
+            throw tactic_exception(ex.what());
         }
     }
     
