@@ -5,15 +5,28 @@ Module Name:
 
     dt2bv_tactic.h
 
-Abstract:
-
-    Tactic that eliminates finite domain data-types.
-
 Author:
 
     nbjorner 2016-07-22
 
-Revision History:
+Tactic Documentation
+
+## Tactic dt2bv
+
+### Short Description
+
+Tactic that eliminates finite domain data-types.
+
+### Example
+
+```z3
+(declare-datatypes ((Color 0)) (((Red) (Blue) (Green) (DarkBlue) (MetallicBlack) (MetallicSilver) (Silver) (Black))))
+(declare-const x Color)
+(declare-const y Color)
+(assert (not (= x y)))
+(assert (not (= x Red)))
+(apply dt2bv)
+```
 
 --*/
 #pragma once
