@@ -107,7 +107,7 @@ struct cofactor_elim_term_ite::imp {
                 frame & fr    = m_frame_stack.back();
                 expr * t      = fr.m_t;
                 bool form_ctx = fr.m_form_ctx;
-                TRACE("cofactor", tout << "processing, form_ctx: " << form_ctx << "\n" << mk_bounded_pp(t, m) << "\n";);
+                TRACE(cofactor, tout << "processing, form_ctx: " << form_ctx << "\n" << mk_bounded_pp(t, m) << "\n";);
 
                 m_owner.checkpoint();
                 
@@ -140,7 +140,7 @@ struct cofactor_elim_term_ite::imp {
                     for (expr* arg : *to_app(t)) {
                         if (m_has_term_ite.is_marked(arg)) {
                             m_has_term_ite.mark(t);
-                            TRACE("cofactor", tout << "saving candidate: " << form_ctx << "\n" << mk_bounded_pp(t, m) << "\n";);
+                            TRACE(cofactor, tout << "saving candidate: " << form_ctx << "\n" << mk_bounded_pp(t, m) << "\n";);
                             save_candidate(t, form_ctx);
                             break;
                         }
@@ -159,7 +159,7 @@ struct cofactor_elim_term_ite::imp {
     };
 
     expr * get_first(expr * t) { 
-        TRACE("cofactor", tout << mk_ismt2_pp(t, m) << "\n";);
+        TRACE(cofactor, tout << mk_ismt2_pp(t, m) << "\n";);
         typedef std::pair<expr *, unsigned> frame;
         expr_fast_mark1         visited;            
         sbuffer<frame>          stack;    
@@ -218,7 +218,7 @@ struct cofactor_elim_term_ite::imp {
        \brief Fuctor for selecting the term if-then-else condition with the most number of occurrences.
     */
     expr * get_best(expr * t) {
-        TRACE("cofactor", tout << mk_ismt2_pp(t, m) << "\n";);
+        TRACE(cofactor, tout << mk_ismt2_pp(t, m) << "\n";);
         typedef std::pair<expr *, unsigned> frame;
         obj_map<expr, unsigned> occs;
         expr_fast_mark1         visited;            
@@ -291,7 +291,7 @@ struct cofactor_elim_term_ite::imp {
             }
         }
         visited.reset();
-        CTRACE("cofactor", best != 0, tout << "best num-occs: " << best_occs << "\n" << mk_ismt2_pp(best, m) << "\n";);
+        CTRACE(cofactor, best != 0, tout << "best num-occs: " << best_occs << "\n" << mk_ismt2_pp(best, m) << "\n";);
         return best;
     }
 
@@ -352,12 +352,12 @@ struct cofactor_elim_term_ite::imp {
                     if (m.is_unique_value(lhs)) {
                         m_term  = rhs;
                         m_value = to_app(lhs); 
-                        TRACE("cofactor", tout << "term:\n" << mk_ismt2_pp(m_term, m) << "\nvalue: " << mk_ismt2_pp(m_value, m) << "\n";);
+                        TRACE(cofactor, tout << "term:\n" << mk_ismt2_pp(m_term, m) << "\nvalue: " << mk_ismt2_pp(m_value, m) << "\n";);
                     }
                     else if (m.is_unique_value(rhs)) {
                         m_term  = lhs;
                         m_value = to_app(rhs);
-                        TRACE("cofactor", tout << "term:\n" << mk_ismt2_pp(m_term, m) << "\nvalue: " << mk_ismt2_pp(m_value, m) << "\n";);
+                        TRACE(cofactor, tout << "term:\n" << mk_ismt2_pp(m_term, m) << "\nvalue: " << mk_ismt2_pp(m_value, m) << "\n";);
                     }
                 }
                 // TODO: bounds
@@ -438,7 +438,7 @@ struct cofactor_elim_term_ite::imp {
 
                 if (m_cache.find(s, t))
                     return true;
-                TRACE("cofactor_ite", tout << "cofactor target:\n" << mk_ismt2_pp(s, m) << "\n";);
+                TRACE(cofactor_ite, tout << "cofactor target:\n" << mk_ismt2_pp(s, m) << "\n";);
                 expr_ref curr(m);
                 curr = s;
                 while (true) {
@@ -459,7 +459,7 @@ struct cofactor_elim_term_ite::imp {
                     m_cofactor.set_cofactor_atom(neg_c);
                     m_cofactor(curr, neg_cofactor);
                     curr = m.mk_ite(c, pos_cofactor, neg_cofactor);
-                    TRACE("cofactor", tout << "cofactor_ite step\n" << mk_ismt2_pp(curr, m) << "\n";);
+                    TRACE(cofactor, tout << "cofactor_ite step\n" << mk_ismt2_pp(curr, m) << "\n";);
                 }
             }
             return false;
@@ -513,7 +513,7 @@ struct cofactor_elim_term_ite::imp {
         }
         
         void cofactor(expr * t, expr_ref & r) {
-            TRACE("cofactor", tout << "cofactor target:\n" << mk_ismt2_pp(t, m) << "\n";);
+            TRACE(cofactor, tout << "cofactor target:\n" << mk_ismt2_pp(t, m) << "\n";);
             expr_ref curr(m);
             curr = t;
             while (true) {
@@ -543,7 +543,7 @@ struct cofactor_elim_term_ite::imp {
                 else {
                     curr = m.mk_ite(c, pos_cofactor, neg_cofactor);
                 }
-                TRACE("cofactor", 
+                TRACE(cofactor, 
                       tout << "cofactor_ite step\n";
                       tout << "cofactor: " << mk_ismt2_pp(c, m) << "\n";
                       tout << mk_ismt2_pp(curr, m) << "\n";);
@@ -565,7 +565,7 @@ struct cofactor_elim_term_ite::imp {
                 m_owner.checkpoint();
                 frame & fr = m_frames.back();
                 expr * t   = fr.first;
-                TRACE("cofactor_bug", tout << "processing: " << t->get_id() << " :first " << fr.second << "\n";);
+                TRACE(cofactor_bug, tout << "processing: " << t->get_id() << " :first " << fr.second << "\n";);
                 if (!is_app(t)) {
                     m_cache.insert(t, t);
                     m_frames.pop_back();
@@ -594,7 +594,7 @@ struct cofactor_elim_term_ite::imp {
                 for (unsigned i = 0; i < num; i++) {
                     expr * arg = to_app(t)->get_arg(i);
                     expr * new_arg = nullptr;
-                    TRACE("cofactor_bug", tout << "collecting child: " << arg->get_id() << "\n";);
+                    TRACE(cofactor_bug, tout << "collecting child: " << arg->get_id() << "\n";);
                     m_cache.find(arg, new_arg);
                     SASSERT(new_arg != 0);
                     if (new_arg != arg)
@@ -622,7 +622,7 @@ struct cofactor_elim_term_ite::imp {
                 if (has_term_ite)
                     m_has_term_ite.insert(new_t);
                 SASSERT(new_t.get() != 0);
-                TRACE("cofactor_bug", tout << "caching: " << t->get_id() << "\n";);
+                TRACE(cofactor_bug, tout << "caching: " << t->get_id() << "\n";);
 #if 0
                 counter ++;
                 verbose_stream() << counter << "\n";
