@@ -29,6 +29,7 @@ Notes:
 #include "ast/fpa_decl_plugin.h"
 #include "tactic/tactical.h"
 #include "util/stats.h"
+#include <iostream>
 
 #include "tactic/core/collect_statistics_tactic.h"
 
@@ -51,8 +52,6 @@ public:
         m_params(p) {
     }
 
-    ~collect_statistics_tactic() override {}
-
     char const* name() const override { return "collect_statistics"; }
 
     tactic * translate(ast_manager & m_) override {
@@ -60,7 +59,7 @@ public:
     }
 
     void updt_params(params_ref const & p) override {
-        m_params = p;
+        m_params.append(p);
     }
 
     void collect_param_descrs(param_descrs & r) override {}
@@ -74,10 +73,10 @@ public:
         for (unsigned i = 0; i < sz; i++)
             for_each_expr(cp, visited, g->form(i));
 
-        std::cout << "(" << std::endl;
+        std::cout << "(\n";
         for (auto const& kv : m_stats) 
-            std::cout << " :" << kv.first << "    " << kv.second << std::endl;
-        std::cout << ")" << std::endl;
+            std::cout << " :" << kv.first << "    " << kv.second << '\n';
+        std::cout << ")\n";
 
         g->inc_depth();
         result.push_back(g.get());
@@ -110,7 +109,6 @@ protected:
         void operator()(quantifier * q) {
             m_stats["quantifiers"]++;
             SASSERT(is_app(q->get_expr()));
-            app * body = to_app(q->get_expr());
             switch (q->get_kind()) {
             case forall_k:
                 m_stats["forall-variables"] += q->get_num_decls();
@@ -128,12 +126,10 @@ protected:
             if (m_stats.find("max-quantification-depth") == m_stats.end() ||
                 m_stats["max-quantification-depth"] < m_qdepth)
                 m_stats["max-quantification-depth"] = m_qdepth;
-            this->operator()(body);
             m_qdepth--;
         }
 
         void operator()(app * n) {
-            m_stats["function-applications"]++;
             this->operator()(n->get_decl());
         }
 
