@@ -24,7 +24,7 @@ Notes:
 #include "tactic/smtlogics/smt_tactic.h"
 #include "qe/qe_tactic.h"
 #include "qe/nlqsat.h"
-#include "qe/qe_lite.h"
+#include "qe/lite/qe_lite_tactic.h"
 #include "nlsat/tactic/qfnra_nlsat_tactic.h"
 
 tactic * mk_nra_tactic(ast_manager & m, params_ref const& p) {
