@@ -17,8 +17,7 @@ Author:
 Notes:
 
 --*/
-#ifndef QFUF_TACTIC_H_
-#define QFUF_TACTIC_H_
+#pragma once
 
 #include "util/params.h"
 class ast_manager;
@@ -30,4 +29,3 @@ tactic * mk_qfuf_tactic(ast_manager & m, params_ref const & p);
   ADD_TACTIC("qfuf", "builtin strategy for solving QF_UF problems.", "mk_qfuf_tactic(m, p)")
 */
 
-#endif
