@@ -16,8 +16,7 @@ Author:
 Notes:
 
 --*/
-#ifndef UFBV_REWRITER_TACTIC_H_
-#define UFBV_REWRITER_TACTIC_H_
+#pragma once
 
 #include "util/params.h"
 class ast_manager;
@@ -29,4 +28,3 @@ tactic * mk_ufbv_rewriter_tactic(ast_manager & m, params_ref const & p = params_
   ADD_TACTIC("ufbv-rewriter",  "Applies UFBV-specific rewriting rules, mainly demodulation.", "mk_quasi_macros_tactic(m, p)")
 */
 
-#endif
