@@ -5,7 +5,7 @@ Copyright (c) 2015 Microsoft Corporation
 --*/
 
 #include "smt/arith_eq_solver.h"
-#include "smt/params/smt_params.h"
+#include "params/smt_params.h"
 #include <iostream>
 
 typedef rational numeral;
