@@ -19,8 +19,7 @@ Revision History:
 --*/
 #pragma once
 
-#ifndef FOR_EACH_FILE_H_
-#define FOR_EACH_FILE_H_
+#pragma once
 
 struct for_each_file_proc {
     virtual bool operator()(const char* file_path) = 0;
@@ -29,5 +28,4 @@ struct for_each_file_proc {
 bool for_each_file(for_each_file_proc& proc, const char* base, const char* suffix);
     
 
-#endif /* FOR_EACH_FILE_H_ */
 
