@@ -31,12 +31,12 @@ static void tst1() {
     ENSURE(append(r, l2, static_cast<list<int> *>(nullptr)) == l2);
     ENSURE(append(r, static_cast<list<int> *>(nullptr), l2) == l2);
     ENSURE(append(r, static_cast<list<int> *>(nullptr), static_cast<list<int> *>(nullptr)) == nullptr);
-    TRACE("list", display(tout, l2->begin(), l2->end()); tout << "\n";);
+    TRACE(list, display(tout, l2->begin(), l2->end()); tout << "\n";);
     list<int> * l5 = append(r, l4, l2);
-    TRACE("list", display(tout, l5->begin(), l5->end()); tout << "\n";);
+    TRACE(list, display(tout, l5->begin(), l5->end()); tout << "\n";);
     list<int> * l6 = append(r, l5, l5);
     (void) l6;
-    TRACE("list", display(tout, l6->begin(), l6->end()); tout << "\n";);
+    TRACE(list, display(tout, l6->begin(), l6->end()); tout << "\n";);
 }
 
 void tst_list() {
