@@ -22,7 +22,7 @@ Revision History:
 
 static void tst1() {
     random_gen r(0);
-    TRACE("random", 
+    TRACE(random, 
           for (unsigned i = 0; i < 1000; i++) {
               tout << r() << "\n";
           });
