@@ -258,13 +258,13 @@ void mpfx_manager::set_core(mpfx & n, mpz_manager<SYNCH> & m, mpz const & v) {
         m_tmp_digits.reset();
         allocate_if_needed(n);
         n.m_sign = m.decompose(v, m_tmp_digits);
-        unsigned sz = m_tmp_digits.size();
+        auto sz = m_tmp_digits.size();
         if (sz > m_int_part_sz)
             throw overflow_exception();
         unsigned * w = words(n);
         for (unsigned i = 0; i < m_frac_part_sz; i++) 
             w[i] = 0;
-        ::copy(sz, m_tmp_digits.c_ptr(), m_int_part_sz, w + m_frac_part_sz);
+        ::copy(sz, m_tmp_digits.data(), m_int_part_sz, w + m_frac_part_sz);
     }
     SASSERT(check(n));
 }
@@ -299,11 +299,11 @@ void mpfx_manager::set_core(mpfx & n, mpq_manager<SYNCH> & m, mpq const & v) {
         }
         m_tmp_digits.reset();
         m.decompose(tmp, m_tmp_digits);
-        unsigned sz = m_tmp_digits.size();
+        auto sz = m_tmp_digits.size();
         if (sz > m_total_sz)
             throw overflow_exception();
         unsigned * w = words(n);
-        ::copy(sz, m_tmp_digits.c_ptr(), m_total_sz, w);
+        ::copy(sz, m_tmp_digits.data(), m_total_sz, w);
     }
     SASSERT(check(n));
 }
@@ -334,7 +334,7 @@ bool mpfx_manager::eq(mpfx const & a, mpfx const & b) const {
 }
 
 bool mpfx_manager::lt(mpfx const & a, mpfx const & b) const {
-    STRACE("mpfx_trace", tout << "[mpfx] ("; display(tout, a); tout << " < "; display(tout, b); tout << ") == ";);
+    STRACE(mpfx_trace, tout << "[mpfx] ("; display(tout, a); tout << " < "; display(tout, b); tout << ") == ";);
     bool r;
     if (is_zero(a)) {
         r = !is_zero(b) && !is_neg(b);
@@ -353,7 +353,7 @@ bool mpfx_manager::lt(mpfx const & a, mpfx const & b) const {
             r = is_pos(b) && ::lt(m_total_sz, words(a), words(b));
         }
     }
-    STRACE("mpfx_trace", tout << "(" << r << " == 1)\n";);
+    STRACE(mpfx_trace, tout << "(" << r << " == 1)\n";);
     return r;
 }
 
@@ -370,7 +370,7 @@ void mpfx_manager::add_sub(bool is_sub, mpfx const & a, mpfx const & b, mpfx & c
         return;
     }
 
-    TRACE("mpfx", tout << (is_sub ? "sub" : "add") << "("; display(tout, a); tout << ", "; display(tout, b); tout << ")\n";);
+    TRACE(mpfx, tout << (is_sub ? "sub" : "add") << "("; display(tout, a); tout << ", "; display(tout, b); tout << ")\n";);
 
     allocate_if_needed(c);
 
@@ -405,31 +405,31 @@ void mpfx_manager::add_sub(bool is_sub, mpfx const & a, mpfx const & b, mpfx & c
         }
         SASSERT(borrow == 0);
     }
-    TRACE("mpfx", tout << "result: "; display(tout, c); tout << "\n";);
+    TRACE(mpfx, tout << "result: "; display(tout, c); tout << "\n";);
     SASSERT(check(c));
 }
 
 void mpfx_manager::add(mpfx const & a, mpfx const & b, mpfx & c) {
-    STRACE("mpfx_trace", tout << "[mpfx] "; display(tout, a); tout << " + "; display(tout, b); tout << " == ";);
+    STRACE(mpfx_trace, tout << "[mpfx] "; display(tout, a); tout << " + "; display(tout, b); tout << " == ";);
     add_sub(false, a, b, c);
-    STRACE("mpfx_trace", display(tout, c); tout << "\n";);  
+    STRACE(mpfx_trace, display(tout, c); tout << "\n";);  
 }
 
 void mpfx_manager::sub(mpfx const & a, mpfx const & b, mpfx & c) {
-    STRACE("mpfx_trace", tout << "[mpfx] "; display(tout, a); tout << " - "; display(tout, b); tout << " == ";);
+    STRACE(mpfx_trace, tout << "[mpfx] "; display(tout, a); tout << " - "; display(tout, b); tout << " == ";);
     add_sub(true, a, b, c);
-    STRACE("mpfx_trace", display(tout, c); tout << "\n";);  
+    STRACE(mpfx_trace, display(tout, c); tout << "\n";);  
 }
 
 void mpfx_manager::mul(mpfx const & a, mpfx const & b, mpfx & c) {
-    STRACE("mpfx_trace", tout << "[mpfx] ("; display(tout, a); tout << ") * ("; display(tout, b); tout << ") " << (m_to_plus_inf ? "<=" : ">=") << " ";);
+    STRACE(mpfx_trace, tout << "[mpfx] ("; display(tout, a); tout << ") * ("; display(tout, b); tout << ") " << (m_to_plus_inf ? "<=" : ">=") << " ";);
     if (is_zero(a) || is_zero(b)) {
         reset(c);
     }
     else {
         allocate_if_needed(c);
         c.m_sign      = a.m_sign ^ b.m_sign;
-        unsigned * r  = m_buffer0.c_ptr();
+        unsigned * r  = m_buffer0.data();
         m_mpn_manager.mul(words(a), m_total_sz, words(b), m_total_sz, r);
         // round result
         unsigned * _r = r + m_frac_part_sz;
@@ -445,14 +445,14 @@ void mpfx_manager::mul(mpfx const & a, mpfx const & b, mpfx & c) {
         for (unsigned i = 0; i < m_total_sz; i++)
             w_c[i] = _r[i];
     }
-    STRACE("mpfx_trace", display(tout, c); tout << "\n";);  
+    STRACE(mpfx_trace, display(tout, c); tout << "\n";);  
     SASSERT(check(c));
 }
 
 void mpfx_manager::div(mpfx const & a, mpfx const & b, mpfx & c) {
     if (is_zero(b)) 
         throw div0_exception();
-    STRACE("mpfx_trace", tout << "[mpfx] ("; display(tout, a); tout << ") / ("; display(tout, b); tout << ") " << (m_to_plus_inf ? "<=" : ">=") << " ";);
+    STRACE(mpfx_trace, tout << "[mpfx] ("; display(tout, a); tout << ") / ("; display(tout, b); tout << ") " << (m_to_plus_inf ? "<=" : ">=") << " ";);
     if (is_zero(a)) {
         reset(c);
     }
@@ -460,7 +460,7 @@ void mpfx_manager::div(mpfx const & a, mpfx const & b, mpfx & c) {
         allocate_if_needed(c);
         c.m_sign    = a.m_sign ^ b.m_sign;
         unsigned * w_a       = words(a);
-        unsigned * w_a_shft  = m_buffer0.c_ptr();
+        unsigned * w_a_shft  = m_buffer0.data();
         unsigned a_shft_sz   = sz(w_a) + m_frac_part_sz; 
         // copy a to buffer 0, and shift by m_frac_part_sz
         for (unsigned i = 0; i < m_frac_part_sz; i++) 
@@ -469,7 +469,7 @@ void mpfx_manager::div(mpfx const & a, mpfx const & b, mpfx & c) {
             w_a_shft[i+m_frac_part_sz] = w_a[i];
         unsigned * w_b       = words(b);
         unsigned b_sz        = sz(w_b);
-        unsigned * w_q       = m_buffer1.c_ptr();
+        unsigned * w_q       = m_buffer1.data();
         if (b_sz > a_shft_sz) {
             if ((c.m_sign == 1) != m_to_plus_inf)
                 set_epsilon(c);
@@ -478,7 +478,7 @@ void mpfx_manager::div(mpfx const & a, mpfx const & b, mpfx & c) {
         }
         else {
             unsigned q_sz        = a_shft_sz - b_sz + 1; 
-            unsigned * w_r       = m_buffer2.c_ptr();
+            unsigned * w_r       = m_buffer2.data();
             unsigned r_sz        = b_sz;
             m_mpn_manager.div(w_a_shft, a_shft_sz,
                               w_b,      b_sz,
@@ -519,12 +519,12 @@ void mpfx_manager::div(mpfx const & a, mpfx const & b, mpfx & c) {
             }
         }
     }
-    STRACE("mpfx_trace", display(tout, c); tout << "\n";);  
+    STRACE(mpfx_trace, display(tout, c); tout << "\n";);  
     SASSERT(check(c));
 }
 
 void mpfx_manager::div2k(mpfx & a, unsigned k) {
-    STRACE("mpfx_trace", tout << "[mpfx] ("; display(tout, a); tout << ") / (2^" << k << ") " << (m_to_plus_inf ? "<=" : ">=") << " ";);
+    STRACE(mpfx_trace, tout << "[mpfx] ("; display(tout, a); tout << ") / (2^" << k << ") " << (m_to_plus_inf ? "<=" : ">=") << " ";);
     if (!is_zero(a) && k > 0) {
         unsigned * w = words(a);
         bool _inc = ((a.m_sign == 1) != m_to_plus_inf) && has_one_at_first_k_bits(m_total_sz, w, k);
@@ -537,7 +537,7 @@ void mpfx_manager::div2k(mpfx & a, unsigned k) {
             reset(a);
         }
     }
-    STRACE("mpfx_trace", display(tout, a); tout << "\n";);  
+    STRACE(mpfx_trace, display(tout, a); tout << "\n";);  
     SASSERT(check(a));
 }
 
@@ -561,7 +561,7 @@ void mpfx_manager::set_plus_epsilon(mpfx & n) {
 }
 
 void mpfx_manager::floor(mpfx & n) {
-    STRACE("mpfx_trace", tout << "[mpfx] Floor["; display(tout, n); tout << "] == ";);
+    STRACE(mpfx_trace, tout << "[mpfx] Floor["; display(tout, n); tout << "] == ";);
     unsigned * w = words(n);
     if (is_neg(n)) {
         bool is_int = true;
@@ -581,11 +581,11 @@ void mpfx_manager::floor(mpfx & n) {
     if (::is_zero(m_int_part_sz, w + m_frac_part_sz))
         reset(n);
     SASSERT(check(n));
-    STRACE("mpfx_trace", display(tout, n); tout << "\n";);  
+    STRACE(mpfx_trace, display(tout, n); tout << "\n";);  
 }
 
 void mpfx_manager::ceil(mpfx & n) {
-    STRACE("mpfx_trace", tout << "[mpfx] Ceiling["; display(tout, n); tout << "] == ";);
+    STRACE(mpfx_trace, tout << "[mpfx] Ceiling["; display(tout, n); tout << "] == ";);
     unsigned * w = words(n);
     if (is_pos(n)) {
         bool is_int = true;
@@ -605,7 +605,7 @@ void mpfx_manager::ceil(mpfx & n) {
     if (::is_zero(m_int_part_sz, w + m_frac_part_sz))
         reset(n);
     SASSERT(check(n));
-    STRACE("mpfx_trace", display(tout, n); tout << "\n";);  
+    STRACE(mpfx_trace, display(tout, n); tout << "\n";);  
 }
 
 void mpfx_manager::power(mpfx const & a, unsigned p, mpfx & b) {
@@ -649,8 +649,8 @@ void mpfx_manager::power(mpfx const & a, unsigned p, mpfx & b) {
             mask = mask << 1;
         }
     }
-    STRACE("mpfx_trace", tout << "[mpfx] ("; display(tout, _a); tout << ") ^ " << _p << (m_to_plus_inf ? "<=" : ">="); display(tout, b); tout << "\n";);
-    TRACE("mpfx_power", display_raw(tout, b); tout << "\n";);
+    STRACE(mpfx_trace, tout << "[mpfx] ("; display(tout, _a); tout << ") ^ " << _p << (m_to_plus_inf ? "<=" : ">="); display(tout, b); tout << "\n";);
+    TRACE(mpfx_power, display_raw(tout, b); tout << "\n";);
     SASSERT(check(b));
 }
 
@@ -811,7 +811,7 @@ void mpfx_manager::display_smt2(std::ostream & out, mpfx const & n) const {
     out << m_mpn_manager.to_string(w, sz, str_buffer.begin(), str_buffer.size());
     if (!is_int(n)) {
         out << " ";
-        unsigned * w = m_buffer0.c_ptr();
+        unsigned * w = m_buffer0.data();
         for (unsigned i = 0; i < m_frac_part_sz; i++)
             w[i] = 0;
         w[m_frac_part_sz] = 1;
@@ -831,10 +831,10 @@ void mpfx_manager::display_decimal(std::ostream & out, mpfx const & n, unsigned
     out << m_mpn_manager.to_string(w + m_frac_part_sz, m_int_part_sz, str_buffer.begin(), str_buffer.size());
     if (!is_int(n)) {
         out << ".";
-        unsigned * frac   = m_buffer0.c_ptr();
+        unsigned * frac   = m_buffer0.data();
         ::copy(m_frac_part_sz, w, m_frac_part_sz, frac);
         unsigned ten      = 10;
-        unsigned * n_frac = m_buffer1.c_ptr();
+        unsigned * n_frac = m_buffer1.data();
         bool frac_is_zero = false;
         unsigned i        = 0;
         while (!frac_is_zero) {
