@@ -57,7 +57,7 @@ class obj_map {
 public:
     struct key_data {
         Key *  m_key = nullptr;
-        Value  m_value;
+        Value  m_value{};
         key_data() = default;
         key_data(Key * k):
             m_key(k) {
