@@ -16,8 +16,7 @@ Author:
 Revision History:
 
 --*/
-#ifndef OBJ_MARK_H_
-#define OBJ_MARK_H_
+#pragma once
 
 #include "util/bit_vector.h"
 
@@ -50,4 +49,3 @@ public:
     void reset() { m_marks.reset(); }
 };
 
-#endif /* OBJ_MARK_H_ */
