@@ -31,11 +31,7 @@ void finalize_rlimit() {
     DEALLOC_MUTEX(g_rlimit_mux);
 }
 
-reslimit::reslimit():
-    m_cancel(0),
-    m_suspend(false),
-    m_count(0),
-    m_limit(std::numeric_limits<uint64_t>::max()) {
+reslimit::reslimit() {
 }
 
 uint64_t reslimit::count() const {
@@ -92,6 +88,19 @@ void reslimit::pop_child() {
     m_children.pop_back();    
 }
 
+void reslimit::pop_child(reslimit* r) {
+    lock_guard lock(*g_rlimit_mux);
+    for (unsigned i = 0; i < m_children.size(); ++i) {
+        if (m_children[i] == r) {
+            m_count += r->m_count;
+            r->m_count = 0;
+            m_children.erase(m_children.begin() + i);
+            return;
+        }
+    }
+}
+
+
 void reslimit::cancel() {
     lock_guard lock(*g_rlimit_mux);
     set_cancel(m_cancel+1);    
@@ -104,7 +113,7 @@ void reslimit::reset_cancel() {
 
 void reslimit::inc_cancel() {
     lock_guard lock(*g_rlimit_mux);
-    set_cancel(m_cancel+1);    
+    set_cancel(m_cancel + 1);
 }
 
 void reslimit::dec_cancel() {
@@ -120,3 +129,39 @@ void reslimit::set_cancel(unsigned f) {
         m_children[i]->set_cancel(f);
     }
 }
+
+
+
+#ifdef POLLING_TIMER
+void reslimit::push_timeout(unsigned ms) {
+    m_num_timers++;
+    if (m_cancel > 0) {
+        ++m_cancel;
+        return;
+    }
+    if (m_timeout_ms != 0) {
+        double ms_taken = 1000 * m_timer.get_seconds();
+        if (ms_taken > m_timeout_ms)
+            return;
+        if (m_timeout_ms - ms_taken < ms)
+            return;
+    }
+    m_timer = timer();
+    m_timeout_ms = ms;
+}
+
+void reslimit::inc_cancel(unsigned k) {
+    lock_guard lock(*g_rlimit_mux);
+    set_cancel(m_cancel + k);        
+}
+
+void reslimit::auto_cancel() {
+    --m_num_timers;
+    dec_cancel();
+}
+
+#else
+void reslimit::auto_cancel() {
+    UNREACHABLE();
+}
+#endif
\ No newline at end of file
